@@ -229,7 +229,7 @@ u8_error_t ctrl_classifier_controller_delete_classifier( ctrl_classifier_control
 
                 data_classifier_destroy( &old_classifier );
             }
-            else if ( U8_ERROR_NONE != ( data_result & U8_ERROR_OBJECT_STILL_REFERENCED ))
+            else if ( u8_error_contains( data_result, U8_ERROR_OBJECT_STILL_REFERENCED ) )
             {
                 /* report this unexpected error */
                 U8_LOG_ERROR( "The classifier cannot be deleted because it is still referenced." );
