@@ -293,7 +293,7 @@ u8_error_t ctrl_multi_step_changer_create_diagram ( ctrl_multi_step_changer_t *t
         (*this_).is_first_step = CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND;
         data_diagram_set_row_id( new_diagram, new_diagram_id );
     }
-    else if ( (create_err & U8_ERROR_DUPLICATE) == U8_ERROR_DUPLICATE )
+    else if ( u8_error_contains( create_err, U8_ERROR_DUPLICATE ) )
     {
         data_diagram_set_row_id( new_diagram, DATA_ROW_ID_VOID );
         const u8_error_t alt_create_err
@@ -356,7 +356,7 @@ u8_error_t ctrl_multi_step_changer_create_diagramelement ( ctrl_multi_step_chang
         (*this_).is_first_step = CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND;
         data_diagramelement_set_row_id( new_diagramelement, new_diagramelement_id );
     }
-    else if ( (create_err & U8_ERROR_DUPLICATE) == U8_ERROR_DUPLICATE )
+    else if ( u8_error_contains( create_err, U8_ERROR_DUPLICATE ) )
     {
         data_diagramelement_set_row_id( new_diagramelement, DATA_ROW_ID_VOID );
         const u8_error_t alt_create_err
@@ -419,7 +419,7 @@ u8_error_t ctrl_multi_step_changer_create_classifier ( ctrl_multi_step_changer_t
         (*this_).is_first_step = CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND;
         data_classifier_set_row_id( new_classifier, new_classifier_id );
     }
-    else if ( (create_err & U8_ERROR_DUPLICATE) == U8_ERROR_DUPLICATE )
+    else if ( u8_error_contains( create_err, U8_ERROR_DUPLICATE ) )
     {
         data_classifier_set_row_id( new_classifier, DATA_ROW_ID_VOID );
         const u8_error_t alt_create_err
@@ -444,41 +444,45 @@ u8_error_t ctrl_multi_step_changer_create_classifier ( ctrl_multi_step_changer_t
         result = create_err;
     }
 
-    if ( (result & U8_ERROR_DUPLICATE) == U8_ERROR_DUPLICATE )
+    if ( u8_error_contains( result, U8_ERROR_DUPLICATE ) )
     {
+        *out_info |= result;
+        result = U8_ERROR_NONE;
+
         /* find an alternative, unused name */
-        char newname_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
-        utf8stringbuf_t full_new_name = UTF8STRINGBUF( newname_buf );
-        const unsigned int name_chars = utf8string_get_length( data_classifier_get_name_const( new_classifier ) );
-        const unsigned int keep_chars = (name_chars < DATA_CLASSIFIER_MAX_NAME_LENGTH-4)
-                                        ? name_chars
-                                        : DATA_CLASSIFIER_MAX_NAME_LENGTH-4;
+        char wish_name_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
+        utf8stringbuf_t wish_name = UTF8STRINGBUF( wish_name_buf );
+        result |= utf8stringbuf_copy_str( wish_name, data_classifier_get_name_const( new_classifier ) );  /* error to be reported to caller */
         {
             bool name_ok = false;
-            static const int MAX_SEARCH_STEP = 1000;
-            static const int FIRST_STEP = 2;
-            for ( int search_step = FIRST_STEP; ( search_step < MAX_SEARCH_STEP )&&( ! name_ok ); search_step ++ )
+            static const uint_fast16_t MAX_SEARCH_STEP = 10000;
+            static const uint_fast16_t FIRST_STEP = 2;
+            for ( uint_fast16_t search_step = FIRST_STEP; ( search_step < MAX_SEARCH_STEP )&&( ! name_ok )&&( result == U8_ERROR_NONE ); search_step ++ )
             {
-                utf8error_t trunc_err
-                    = utf8stringbuf_copy_region_from_str( full_new_name,
-                                                          data_classifier_get_name_const( new_classifier ),
-                                                          0,  /* start */
-                                                          keep_chars  /* length */
-                                                        );
-                trunc_err |= utf8stringbuf_append_str( full_new_name, "'" );
-                trunc_err |= utf8stringbuf_append_int( full_new_name, search_step );
-                data_classifier_set_name( new_classifier, utf8stringbuf_get_string( full_new_name ) );
-                if ( trunc_err != UTF8ERROR_SUCCESS )
+                char new_name_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
+                utf8stringbuf_t new_name = UTF8STRINGBUF( new_name_buf );
+                const u8_error_t trunc_err
+                    = ctrl_multi_step_changer_private_propose_classifier_name( this_,
+                                                                               utf8stringbuf_get_string( wish_name ),
+                                                                               search_step,
+                                                                               new_name
+                                                                             );
+                if ( trunc_err != U8_ERROR_NONE )
                 {
-                    U8_TRACE_INFO_STR("Name truncated at search for alternative:", utf8stringbuf_get_string( full_new_name ) );
+                    U8_TRACE_INFO_STR("Name truncated at search for alternative:", utf8stringbuf_get_string( new_name ) );
                 }
-
-                result = ctrl_classifier_controller_create_classifier( classifier_ctrl,
-                                                                       new_classifier,
-                                                                       (*this_).is_first_step,
-                                                                       &new_classifier_id
-                                                                     );
-                if ( result == U8_ERROR_NONE )
+                data_classifier_set_name( new_classifier, utf8stringbuf_get_string( new_name ) );
+                const u8_error_t retry_err
+                    = ctrl_classifier_controller_create_classifier( classifier_ctrl,
+                                                                    new_classifier,
+                                                                    (*this_).is_first_step,
+                                                                    &new_classifier_id
+                                                                  );
+                if ( u8_error_contains( retry_err, U8_ERROR_DUPLICATE ) )
+                {
+                    *out_info |= retry_err;
+                }
+                else if ( retry_err == U8_ERROR_NONE )
                 {
                     name_ok = true;  /* name unused */
                     (*this_).is_first_step = CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND;
@@ -487,7 +491,7 @@ u8_error_t ctrl_multi_step_changer_create_classifier ( ctrl_multi_step_changer_t
                 }
                 else
                 {
-                    name_ok = false;  /* name already in use */
+                    result |= retry_err;
                 }
             }
         }
@@ -531,7 +535,7 @@ u8_error_t ctrl_multi_step_changer_create_feature ( ctrl_multi_step_changer_t *t
         (*this_).is_first_step = CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND;
         data_feature_set_row_id( new_feature, new_feature_id );
     }
-    else if ( (create_err & U8_ERROR_DUPLICATE) == U8_ERROR_DUPLICATE )
+    else if ( u8_error_contains( create_err, U8_ERROR_DUPLICATE) )
     {
         data_feature_set_row_id( new_feature, DATA_ROW_ID_VOID );
         const u8_error_t alt_create_err
@@ -594,7 +598,7 @@ u8_error_t ctrl_multi_step_changer_create_relationship ( ctrl_multi_step_changer
         (*this_).is_first_step = CTRL_UNDO_REDO_ACTION_BOUNDARY_APPEND;
         data_relationship_set_row_id( new_relationship, new_relationship_id );
     }
-    else if ( (create_err & U8_ERROR_DUPLICATE) == U8_ERROR_DUPLICATE )
+    else if ( u8_error_contains( create_err, U8_ERROR_DUPLICATE) )
     {
         data_relationship_set_row_id( new_relationship, DATA_ROW_ID_VOID );
         const u8_error_t alt_create_err
@@ -649,6 +653,35 @@ u8_error_t ctrl_multi_step_changer_update_diagram_parent_id ( ctrl_multi_step_ch
     return result;
 }
 
+/* ================================ propose names of classifiers ================================ */
+
+u8_error_t ctrl_multi_step_changer_private_propose_classifier_name ( ctrl_multi_step_changer_t *this_,
+                                                                     const char* base_classifier_name,
+                                                                     uint_fast16_t iteration,
+                                                                     utf8stringbuf_t out_name )
+{
+    U8_TRACE_BEGIN();
+    const size_t RESERVED_FOR_NUMBER = 5;
+    assert( NULL != base_classifier_name );
+    assert( utf8stringbuf_get_size(out_name) > RESERVED_FOR_NUMBER );
+    u8_error_t result = U8_ERROR_NONE;
+
+    /* find an alternative, unused name */
+    /* copy the base_classifier_name to newname_buf */
+    {
+        utf8stringbuf_t shortened_new_name
+            = utf8stringbuf_init( utf8stringbuf_get_size(out_name)-RESERVED_FOR_NUMBER, utf8stringbuf_get_string(out_name) );
+        result |= utf8stringbuf_copy_str( shortened_new_name, base_classifier_name );
+        /* null termination is guaranteed, also this function does not cut an utf8 code point in the middle. */
+    }
+    /* append a separator and the iteration number */
+    result |= utf8stringbuf_append_str( out_name, "-" );
+    result |= utf8stringbuf_append_int( out_name, iteration );
+
+    U8_TRACE_END_ERR( result );
+    return result;
+}
+
 
 /*
 Copyright 2016-2023 Andreas Warnke
