@@ -71,15 +71,15 @@ u8_error_t data_visible_set_load( data_visible_set_t *this_, data_row_id_t diagr
         /* load diagram */
         db_err = data_database_reader_get_diagram_by_id ( db_reader, diagram_id, &((*this_).diagram) );
 
-        if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading a diagram" );
         }
-        if ( U8_ERROR_ARRAY_BUFFER_EXCEEDED == (db_err & U8_ERROR_ARRAY_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at loading a diagram" );
         }
-        if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED)) )
+        if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             /* error at loading */
             data_diagram_reinit_empty( &((*this_).diagram) );
@@ -94,15 +94,15 @@ u8_error_t data_visible_set_load( data_visible_set_t *this_, data_row_id_t diagr
                                                                       &((*this_).visible_classifier_count)
                                                                     );
 
-        if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading visible classifiers of a diagram" );
         }
-        if ( U8_ERROR_ARRAY_BUFFER_EXCEEDED == (db_err & U8_ERROR_ARRAY_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at loading visible classifiers of a diagram" );
         }
-        if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED)) )
+        if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             /* error at loading */
             (*this_).visible_classifier_count = 0;
@@ -117,15 +117,15 @@ u8_error_t data_visible_set_load( data_visible_set_t *this_, data_row_id_t diagr
                                                                    &((*this_).feature_count)
                                                                  );
 
-        if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading features of a diagram" );
         }
-        if ( U8_ERROR_ARRAY_BUFFER_EXCEEDED == (db_err & U8_ERROR_ARRAY_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at loading features of a diagram" );
         }
-        if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED)) )
+        if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             /* error at loading */
             (*this_).feature_count = 0;
@@ -140,15 +140,15 @@ u8_error_t data_visible_set_load( data_visible_set_t *this_, data_row_id_t diagr
                                                                         &((*this_).relationship_count)
                                                                       );
 
-        if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading relationships of a diagram" );
         }
-        if ( U8_ERROR_ARRAY_BUFFER_EXCEEDED == (db_err & U8_ERROR_ARRAY_BUFFER_EXCEEDED) )
+        if ( u8_error_contains( db_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             U8_LOG_ERROR( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at loading relationships of a diagram" );
         }
-        if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED)) )
+        if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED|U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
         {
             /* error at loading */
             (*this_).relationship_count = 0;
