@@ -2,7 +2,9 @@
 
 #include "gui_attributes_editor.h"
 #include "gtk_helper/gtk_helper_tree_model.h"
+#include "draw/draw_stereotype_image.h"
 #include "u8/u8_trace.h"
+#include "ctrl_simple_changer.h"
 #include "data_table.h"
 #include "data_id.h"
 #include "utf8stringbuf/utf8string.h"
@@ -579,7 +581,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                 db_err = data_database_reader_get_classifier_by_id ( (*this_).db_reader, data_id_get_row_id(&id), &((*this_).private_classifier_cache) );
                 data_id_replace( &((*this_).selected_object_id), &id );
 
-                if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+                if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading a classifier" );
                     gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -587,7 +589,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                                                              GUI_SIMPLE_MESSAGE_CONTENT_STRING_TRUNCATED
                                                            );
                 }
-                if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED)) )
+                if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     /* error at loading */
                     data_classifier_reinit_empty( &((*this_).private_classifier_cache) );
@@ -611,7 +613,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                 db_err = data_database_reader_get_feature_by_id ( (*this_).db_reader, data_id_get_row_id(&id), &((*this_).private_feature_cache) );
                 data_id_replace( &((*this_).selected_object_id), &id );
 
-                if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+                if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading a feature" );
                     gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -619,7 +621,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                                                              GUI_SIMPLE_MESSAGE_CONTENT_STRING_TRUNCATED
                                                            );
                 }
-                if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED)) )
+                if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     /* error at loading */
                     data_feature_reinit_empty( &((*this_).private_feature_cache) );
@@ -643,7 +645,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                 db_err = data_database_reader_get_relationship_by_id ( (*this_).db_reader, data_id_get_row_id(&id), &((*this_).private_relationship_cache) );
                 data_id_replace( &((*this_).selected_object_id), &id );
 
-                if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+                if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading a relationship" );
                     gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -651,7 +653,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                                                              GUI_SIMPLE_MESSAGE_CONTENT_STRING_TRUNCATED
                                                            );
                 }
-                if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED)) )
+                if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     /* error at loading */
                     data_relationship_reinit_empty( &((*this_).private_relationship_cache) );
@@ -686,7 +688,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                 db_err = data_database_reader_get_diagram_by_id ( (*this_).db_reader, data_id_get_row_id(&id), &((*this_).private_diagram_cache) );
                 data_id_replace( &((*this_).selected_object_id), &id );
 
-                if ( U8_ERROR_STRING_BUFFER_EXCEEDED == (db_err & U8_ERROR_STRING_BUFFER_EXCEEDED) )
+                if ( u8_error_contains( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     U8_LOG_ERROR( "U8_ERROR_STRING_BUFFER_EXCEEDED at loading a diagram" );
                     gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -694,7 +696,7 @@ void gui_attributes_editor_private_load_object ( gui_attributes_editor_t *this_,
                                                              GUI_SIMPLE_MESSAGE_CONTENT_STRING_TRUNCATED
                                                            );
                 }
-                if ( U8_ERROR_NONE != (db_err & ~(U8_ERROR_STRING_BUFFER_EXCEEDED)) )
+                if ( u8_error_more_than( db_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     /* error at loading */
                     data_diagram_reinit_empty( &((*this_).private_diagram_cache) );
@@ -750,18 +752,23 @@ void gui_attributes_editor_private_name_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_CLASSIFIER:
         {
-            const char* unchanged_text;
-            unchanged_text = data_classifier_get_name_const( &((*this_).private_classifier_cache) );
+            const char *const unchanged_text
+                = data_classifier_get_name_const( &((*this_).private_classifier_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
-                ctrl_classifier_controller_t *class_ctrl;
-                class_ctrl = ctrl_controller_get_classifier_control_ptr ( (*this_).controller );
+                u8_error_t handled_err;
+                {
+                    ctrl_simple_changer_t name_disambiguator;
+                    ctrl_simple_changer_init( &name_disambiguator, (*this_).controller, (*this_).db_reader );
+                    ctrl_err = ctrl_simple_changer_update_classifier_name( &name_disambiguator,
+                                                                           data_id_get_row_id( &((*this_).selected_object_id) ),
+                                                                           text,
+                                                                           &handled_err
+                                                                         );
+                    ctrl_simple_changer_destroy( &name_disambiguator );
+                }
 
-                ctrl_err = ctrl_classifier_controller_update_classifier_name( class_ctrl,
-                                                                              data_id_get_row_id( &((*this_).selected_object_id) ),
-                                                                              text
-                                                                            );
-                if ( U8_ERROR_DUPLICATE_NAME == ctrl_err )
+                if ( u8_error_contains( handled_err, U8_ERROR_DUPLICATE_NAME ) )
                 {
                     gui_simple_message_to_user_show_message_with_name( (*this_).message_to_user,
                                                                        GUI_SIMPLE_MESSAGE_TYPE_ERROR,
@@ -769,14 +776,14 @@ void gui_attributes_editor_private_name_commit_changes ( gui_attributes_editor_t
                                                                        text
                                                                      );
                 }
-                else if ( U8_ERROR_STRING_BUFFER_EXCEEDED == ctrl_err )
+                else if ( u8_error_contains( ctrl_err, U8_ERROR_STRING_BUFFER_EXCEEDED ) )
                 {
                     gui_simple_message_to_user_show_message( (*this_).message_to_user,
                                                              GUI_SIMPLE_MESSAGE_TYPE_WARNING,
                                                              GUI_SIMPLE_MESSAGE_CONTENT_STRING_TRUNCATED
                                                            );
                 }
-                else if ( U8_ERROR_READ_ONLY_DB == ctrl_err )
+                else if ( u8_error_contains( ctrl_err, U8_ERROR_READ_ONLY_DB ) )
                 {
                     /* notify read-only warning to user */
                     gui_simple_message_to_user_show_message( (*this_).message_to_user,
@@ -794,8 +801,8 @@ void gui_attributes_editor_private_name_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_FEATURE:
         {
-            const char* unchanged_text;
-            unchanged_text = data_feature_get_key_const( &((*this_).private_feature_cache) );
+            const char *const unchanged_text
+                = data_feature_get_key_const( &((*this_).private_feature_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
                 ctrl_classifier_controller_t *class_ctrl;
@@ -830,8 +837,8 @@ void gui_attributes_editor_private_name_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_RELATIONSHIP:
         {
-            const char* unchanged_text;
-            unchanged_text = data_relationship_get_name_const( &((*this_).private_relationship_cache) );
+            const char *const unchanged_text
+                = data_relationship_get_name_const( &((*this_).private_relationship_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
                 ctrl_classifier_controller_t *class_ctrl;
@@ -873,8 +880,8 @@ void gui_attributes_editor_private_name_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_DIAGRAM:
         {
-            const char* unchanged_text;
-            unchanged_text = data_diagram_get_name_const( &((*this_).private_diagram_cache) );
+            const char *const unchanged_text
+                = data_diagram_get_name_const( &((*this_).private_diagram_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
                 ctrl_diagram_controller_t *diag_ctrl;
@@ -1052,8 +1059,8 @@ void gui_attributes_editor_private_type_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_CLASSIFIER:
         {
-            data_classifier_type_t unchanged_main_type;
-            unchanged_main_type = data_classifier_get_main_type( &((*this_).private_classifier_cache) );
+            const data_classifier_type_t unchanged_main_type
+                = data_classifier_get_main_type( &((*this_).private_classifier_cache) );
             if ( obj_type != unchanged_main_type )
             {
                 ctrl_classifier_controller_t *class_ctrl;
@@ -1078,8 +1085,8 @@ void gui_attributes_editor_private_type_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_FEATURE:
         {
-            data_feature_type_t unchanged_main_type;
-            unchanged_main_type = data_feature_get_main_type( &((*this_).private_feature_cache) );
+            const data_feature_type_t unchanged_main_type
+                = data_feature_get_main_type( &((*this_).private_feature_cache) );
             if ( obj_type != unchanged_main_type )
             {
                 ctrl_classifier_controller_t *class_ctrl;
@@ -1104,8 +1111,8 @@ void gui_attributes_editor_private_type_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_RELATIONSHIP:
         {
-            data_relationship_type_t unchanged_main_type;
-            unchanged_main_type = data_relationship_get_main_type( &((*this_).private_relationship_cache) );
+            const data_relationship_type_t unchanged_main_type
+                = data_relationship_get_main_type( &((*this_).private_relationship_cache) );
             if ( obj_type != unchanged_main_type )
             {
                 ctrl_classifier_controller_t *class_ctrl;
@@ -1137,8 +1144,8 @@ void gui_attributes_editor_private_type_commit_changes ( gui_attributes_editor_t
 
         case DATA_TABLE_DIAGRAM:
         {
-            data_diagram_type_t unchanged_type;
-            unchanged_type = data_diagram_get_diagram_type( &((*this_).private_diagram_cache) );
+            const data_diagram_type_t unchanged_type
+                = data_diagram_get_diagram_type( &((*this_).private_diagram_cache) );
             if ( obj_type != unchanged_type )
             {
                 ctrl_diagram_controller_t *diag_ctrl;
@@ -1203,22 +1210,48 @@ void gui_attributes_editor_private_description_commit_changes ( gui_attributes_e
 
         case DATA_TABLE_CLASSIFIER:
         {
-            const char* unchanged_text;
-            unchanged_text = data_classifier_get_description_const( &((*this_).private_classifier_cache) );
+            const char *const unchanged_text
+                = data_classifier_get_description_const( &((*this_).private_classifier_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
                 ctrl_update_err = ctrl_classifier_controller_update_classifier_description( class_ctrl,
                                                                                             data_id_get_row_id( &((*this_).selected_object_id) ),
                                                                                             text
                                                                                           );
+
+                /* report errors in svg images in description in case of stereotype: */
+                const data_classifier_type_t main_type
+                    = data_classifier_get_main_type( &((*this_).private_classifier_cache) );
+                if ( main_type == DATA_CLASSIFIER_TYPE_STEREOTYPE )
+                {
+                    geometry_rectangle_t view_rect;
+                    u8_error_info_t svg_err_info;
+                    draw_stereotype_image_t svg_parser;
+                    draw_stereotype_image_init( &svg_parser );
+                    const u8_error_t svg_err
+                        = draw_stereotype_image_parse_svg_xml( &svg_parser,
+                                                               text,  /* drawing_directives */
+                                                               &view_rect,
+                                                               &svg_err_info
+                                                             );
+                    draw_stereotype_image_destroy( &svg_parser );
+                    if ( svg_err == U8_ERROR_NOT_FOUND )
+                    {
+                        U8_TRACE_INFO( "the stereotype has no image." );
+                    }
+                    else if ( svg_err != U8_ERROR_NONE )
+                    {
+                        gui_simple_message_to_user_show_error_info( (*this_).message_to_user, &svg_err_info );
+                    }
+                }
             }
         }
         break;
 
         case DATA_TABLE_FEATURE:
         {
-            const char* unchanged_text;
-            unchanged_text = data_feature_get_description_const( &((*this_).private_feature_cache) );
+            const char *const unchanged_text
+                = data_feature_get_description_const( &((*this_).private_feature_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
                 ctrl_update_err = ctrl_classifier_controller_update_feature_description( class_ctrl,
@@ -1231,8 +1264,8 @@ void gui_attributes_editor_private_description_commit_changes ( gui_attributes_e
 
         case DATA_TABLE_RELATIONSHIP:
         {
-            const char* unchanged_text;
-            unchanged_text = data_relationship_get_description_const( &((*this_).private_relationship_cache) );
+            const char *const unchanged_text
+                = data_relationship_get_description_const( &((*this_).private_relationship_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
                 ctrl_update_err = ctrl_classifier_controller_update_relationship_description( class_ctrl,
@@ -1252,8 +1285,8 @@ void gui_attributes_editor_private_description_commit_changes ( gui_attributes_e
 
         case DATA_TABLE_DIAGRAM:
         {
-            const char* unchanged_text;
-            unchanged_text = data_diagram_get_description_const( &((*this_).private_diagram_cache) );
+            const char *const unchanged_text
+                = data_diagram_get_description_const( &((*this_).private_diagram_cache) );
             if ( ! utf8string_equals_str( text, unchanged_text ) )
             {
                 ctrl_update_err = ctrl_diagram_controller_update_diagram_description( diag_ctrl,
