@@ -2,7 +2,7 @@
 
 #include "sketch/gui_sketch_object_creator.h"
 #include "geometry/geometry_rectangle.h"
-//#include "ctrl_multi_step_changer.h"
+#include "ctrl_multi_step_changer.h"
 #include "data_table.h"
 #include "data_id.h"
 #include "u8/u8_trace.h"
@@ -51,14 +51,6 @@ u8_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_creat
 
     u8_error_t c_result;
 
-    /* get classifier controller */
-    ctrl_classifier_controller_t *classifier_control;
-    classifier_control = ctrl_controller_get_classifier_control_ptr( (*this_).controller );
-
-    /* get diagram controller */
-    ctrl_diagram_controller_t *diagram_control;
-    diagram_control = ctrl_controller_get_diagram_control_ptr( (*this_).controller );
-
     /* get type of diagram */
     data_diagram_type_t diag_type = DATA_DIAGRAM_TYPE_LIST;
     {
@@ -83,48 +75,15 @@ u8_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_creat
     type_of_new_classifier = data_rules_get_default_classifier_type( &((*this_).data_rules), diag_type );
 
     /* propose a name */
-    // char newname_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
-    // utf8stringbuf_t full_new_name = UTF8STRINGBUF( newname_buf );
-    // gui_sketch_object_creator_private_propose_classifier_name( this_, type_of_new_classifier, full_new_name );
-
-    /* find a good, unused name */
-    char newname_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
-    utf8stringbuf_t full_new_name = UTF8STRINGBUF( newname_buf );
-    {
-        bool name_ok = false;
-        static const int MAX_SEARCH_STEP = 64;
-        static int my_counter = 0;
-        for ( int search_step = 0; ( search_step < MAX_SEARCH_STEP )&&( ! name_ok ); search_step ++ )
-        {
-            my_counter ++;
-            gui_sketch_object_creator_private_propose_classifier_name( this_, type_of_new_classifier, full_new_name );
-            utf8stringbuf_append_str( full_new_name, "-" );
-            utf8stringbuf_append_int( full_new_name, my_counter+search_step );
-
-            /* check if that name is already in use */
-            const u8_error_t exists_err
-                = data_database_reader_get_classifier_by_name( (*this_).db_reader,
-                                                               utf8stringbuf_get_string( full_new_name ),
-                                                               &((*this_).private_temp_classifier)
-                                                             );
-            if ( U8_ERROR_NONE == exists_err )
-            {
-                data_classifier_destroy ( &((*this_).private_temp_classifier) );
-                name_ok = false;  /* name already in use */
-            }
-            else
-            {
-                name_ok = true;  /* name unused */
-            }
-        }
-    }
+    const char *const full_new_name
+        = gui_sketch_object_creator_private_propose_classifier_name( this_, type_of_new_classifier );
 
     /* define classifier */
     const u8_error_t d_err
         = data_classifier_init_new ( &((*this_).private_temp_classifier),
                                      type_of_new_classifier,
                                      "",  /* stereotype */
-                                     utf8stringbuf_get_string( full_new_name ),
+                                     full_new_name,
                                      "",  /* description */
                                      x_order,
                                      y_order,
@@ -135,20 +94,24 @@ u8_error_t gui_sketch_object_creator_create_classifier ( gui_sketch_object_creat
         U8_LOG_ERROR_HEX("data_classifier_init_new failed in gui_sketch_object_creator_create_classifier:",d_err);
     }
 
-    // ctrl_multi_step_changer_t multi_stepper;
-    // ctrl_multi_step_changer_init( &multi_stepper, &controller, &db_reader );
-    // u8_error_t* out_info;
-
-    c_result = ctrl_classifier_controller_create_classifier ( classifier_control,
+    /* create classifier, adapt name if necessary: */
+    {
+        ctrl_multi_step_changer_t multi_stepper;
+        ctrl_multi_step_changer_init( &multi_stepper, (*this_).controller, (*this_).db_reader );
+        u8_error_t out_info;
+        c_result = ctrl_multi_step_changer_create_classifier( &multi_stepper,
                                                               &((*this_).private_temp_classifier),
-                                                              CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
-                                                              out_classifier_id
+                                                              &out_info
                                                             );
-
-    // ctrl_multi_step_changer_destroy( &multi_stepper );
+        *out_classifier_id = data_classifier_get_row_id( &((*this_).private_temp_classifier) );
+        ctrl_multi_step_changer_destroy( &multi_stepper );
+    }
 
     if ( U8_ERROR_NONE == c_result )
     {
+        /* get diagram controller */
+        ctrl_diagram_controller_t *const diagram_control = ctrl_controller_get_diagram_control_ptr( (*this_).controller );
+
         data_diagramelement_t new_diagele;
         data_diagramelement_init_new ( &new_diagele,
                                        diagram_id,
@@ -260,9 +223,8 @@ u8_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creator_
     ctrl_diagram_controller_t *diag_control;
     diag_control = ctrl_controller_get_diagram_control_ptr ( (*this_).controller );
 
-    char newname_buf[DATA_DIAGRAM_MAX_NAME_SIZE];
-    utf8stringbuf_t new_name = UTF8STRINGBUF( newname_buf );
-    gui_sketch_object_creator_private_propose_diagram_name( this_, new_name );
+    const char *const new_name
+        = gui_sketch_object_creator_private_propose_diagram_name( this_ );
 
     /* create the diagram */
     const u8_error_t d_err
@@ -270,7 +232,7 @@ u8_error_t gui_sketch_object_creator_create_diagram ( gui_sketch_object_creator_
                                  parent_diagram_id,
                                  DATA_DIAGRAM_TYPE_UML_COMPONENT_DIAGRAM,
                                  "",
-                                 utf8stringbuf_get_string(new_name),
+                                 new_name,
                                  "",
                                  list_order,
                                  DATA_DIAGRAM_FLAG_NONE
@@ -484,16 +446,15 @@ u8_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creator_
     }
 
     /* find a good default name */
-    char newname_buf[DATA_CLASSIFIER_MAX_NAME_SIZE];
-    utf8stringbuf_t full_new_name = UTF8STRINGBUF( newname_buf );
-    gui_sketch_object_creator_private_propose_feature_name( this_, new_feature_type, full_new_name );
+    const char *const full_new_name
+        = gui_sketch_object_creator_private_propose_feature_name( this_, new_feature_type );
 
     /* define feature struct */
     const u8_error_t data_err
         = data_feature_init_new( &((*this_).private_temp_feature),
                                  new_feature_type,
                                  parent_classifier_id,
-                                 utf8stringbuf_get_string( full_new_name ),
+                                 full_new_name,
                                  "",  /* type/value */
                                  "",
                                  list_order
@@ -554,35 +515,52 @@ u8_error_t gui_sketch_object_creator_create_feature ( gui_sketch_object_creator_
     return c_result;
 }
 
-void gui_sketch_object_creator_private_propose_diagram_name( gui_sketch_object_creator_t *this_, utf8stringbuf_t out_name )
+const char* gui_sketch_object_creator_private_propose_diagram_name( gui_sketch_object_creator_t *this_ )
 {
     static int cycle_names = 0;
-    static char *(NAMES[8]) = {"New Overview","New Context","New Structure","New Deployment","New Lifecycle","New Errors","New Use Cases","New Sequence"};
+    static const char *const (NAMES[8])
+        = {"New Overview","New Context","New Structure","New Deployment","New Lifecycle","New Errors","New Use Cases","New Sequence"};
 
     cycle_names ++;
-    utf8stringbuf_copy_str( out_name, NAMES[cycle_names&0x07] );
+
+    return NAMES[cycle_names&0x07];
 }
 
-void gui_sketch_object_creator_private_propose_classifier_name( gui_sketch_object_creator_t *this_,
-                                                                data_classifier_type_t c_type,
-                                                                utf8stringbuf_t out_name )
+const char* gui_sketch_object_creator_private_propose_classifier_name( gui_sketch_object_creator_t *this_, data_classifier_type_t c_type )
 {
+    const char* result = "";
+
     static int cycle_names = 0;
-    static char *(BLOCK_NAMES[8]) = {"New DRAM","New SoC","New NAND","New NOR","New PMIC","New Watchdog","New CPU","New SRAM"};
-    static char *(REQUIREMENT_NAMES[8]) = {"New Reaction Time","New Startup Time","New Latency","New Resource Consumption","New Update","New Fault Tolerance","New Availability","New Hardware Abstraction"};
-    static char *(ACTOR_NAMES[8]) = {"New Customer","New Database","New Service/Maintenance","New Operator","New Backend/Server","New Authorities","New Hacker/Cheater","New Peer/Client"};
-    static char *(USECASE_NAMES[8]) = {"New Get Status","New Perform Transaction","New SW Update","New Pay Order","New Deliver","New Debug","New Prove Eventlog","New Manage Rights"};
-    static char *(BOUNDARIES_NAMES[8]) = {"New Controller SW","New Machine","New Backend","New Virtual Machine","New Security Module","New Terminal","New Smart Device","New PC"};
-    static char *(ACTIVITY_NAMES[8]) = {"New Startup","New SW Update","New Background Scan","New Sleep","New User Input","New Normal Operation","New Error Reporting","New Idle"};
-    static char *(STATE_NAMES[8]) = {"New Off","New Starting","New On","New Debugging","New Wait","New Shutdown","New Send","New Receive"};
-    static char *(DIAGREF_NAMES[8]) = {"New Startup","New Data Upload","New Data Download","New Shutdown","New Suspend and Resume","New Background Activities","New Error Notification","New SW Update"};
-    static char *(COMPONENT_NAMES[8]) = {"New Persistence","New ErrorLogger","New UserInterface","New PeripheralControl","New Monitor","New ServiceDiscovery","New LifecycleManager","New Controller"};
-    static char *(ARTIFACT_NAMES[8]) = {"New Firmware","New Code","New Data","New Settings","New Log","New ErrorReport","New RuleSet","New Inventory"};
-    static char *(IF_NAMES[8]) = {"New Authentication_IF","New Log_IF","New TraceChannel_IF","New Update_IF","New DataSync_IF","New DataLink_IF","New AliveSignal_IF","New PowerControl_IF"};
-    static char *(CLASS_NAMES[8]) = {"New Serializer","New Deserializer","New CompressionAlg","New Transformer","New Wrapper","New EventLoop","New RingBuffer","New Multiplexer"};
-    static char *(PACKAGE_NAMES[8]) = {"New Drivers","New Platform Services","New User Applications","New Utilities","New Debug Tools","New Authentication and Authorization","New Controller","New Maintenance Tools"};
-    static char *(NOTE_NAMES[8]) = {"New Note","New Comment","New Hint","New Todo","New Remark","New Question","New Rationale","New Proposal"};
-    static char *(STEREOTYPE_NAMES[8]) = {"New transient","New persistent","New 3rd-party","New entity","New database","New decision","New testcase","New copy-of"};
+    static const char *const (BLOCK_NAMES[8])
+        = {"New DRAM","New SoC","New NAND","New NOR","New PMIC","New Watchdog","New CPU","New SRAM"};
+    static const char *(REQUIREMENT_NAMES[8])
+        = {"New Reaction Time","New Startup Time","New Latency","New Resource Consumption","New Update","New Fault Tolerance","New Availability","New Hardware Abstraction"};
+    static const char *const (ACTOR_NAMES[8])
+        = {"New Customer","New Database","New Service/Maintenance","New Operator","New Backend/Server","New Authorities","New Hacker/Cheater","New Peer/Client"};
+    static const char *const (USECASE_NAMES[8])
+        = {"New Get Status","New Perform Transaction","New SW Update","New Pay Order","New Deliver","New Debug","New Prove Eventlog","New Manage Rights"};
+    static const char *const (BOUNDARIES_NAMES[8])
+        = {"New Controller SW","New Machine","New Backend","New Virtual Machine","New Security Module","New Terminal","New Smart Device","New PC"};
+    static const char *const (ACTIVITY_NAMES[8])
+        = {"New Startup","New SW Update","New Background Scan","New Sleep","New User Input","New Normal Operation","New Error Reporting","New Idle"};
+    static const char *const (STATE_NAMES[8])
+        = {"New Off","New Starting","New On","New Debugging","New Wait","New Shutdown","New Send","New Receive"};
+    static const char *const (DIAGREF_NAMES[8])
+        = {"New Startup","New Data Upload","New Data Download","New Shutdown","New Suspend and Resume","New Background Activities","New Error Notification","New SW Update"};
+    static const char *const (COMPONENT_NAMES[8])
+        = {"New Persistence","New ErrorLogger","New UserInterface","New PeripheralControl","New Monitor","New ServiceDiscovery","New LifecycleManager","New Controller"};
+    static const char *const (ARTIFACT_NAMES[8])
+        = {"New Firmware","New Code","New Data","New Settings","New Log","New ErrorReport","New RuleSet","New Inventory"};
+    static const char *const (IF_NAMES[8])
+        = {"New Authentication_IF","New Log_IF","New TraceChannel_IF","New Update_IF","New DataSync_IF","New DataLink_IF","New AliveSignal_IF","New PowerControl_IF"};
+    static const char *const (CLASS_NAMES[8])
+        = {"New Serializer","New Deserializer","New CompressionAlg","New Transformer","New Wrapper","New EventLoop","New RingBuffer","New Multiplexer"};
+    static const char *const (PACKAGE_NAMES[8])
+        = {"New Drivers","New Platform Services","New User Applications","New Utilities","New Debug Tools","New Authentication and Authorization","New Controller","New Maintenance Tools"};
+    static const char *const (NOTE_NAMES[8])
+        = {"New Note","New Comment","New Hint","New Todo","New Remark","New Question","New Rationale","New Proposal"};
+    static const char *const (STEREOTYPE_NAMES[8])
+        = {"New transient","New persistent","New 3rd-party","New entity","New database","New decision","New testcase","New copy-of"};
 
     cycle_names ++;
 
@@ -591,31 +569,31 @@ void gui_sketch_object_creator_private_propose_classifier_name( gui_sketch_objec
         case DATA_CLASSIFIER_TYPE_BLOCK:
         case DATA_CLASSIFIER_TYPE_CONSTRAINT_BLOCK:
         {
-            utf8stringbuf_copy_str( out_name, BLOCK_NAMES[cycle_names&0x07] );
+            result = BLOCK_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_REQUIREMENT:
         {
-            utf8stringbuf_copy_str( out_name, REQUIREMENT_NAMES[cycle_names&0x07] );
+            result = REQUIREMENT_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_ACTOR:
         {
-            utf8stringbuf_copy_str( out_name, ACTOR_NAMES[cycle_names&0x07] );
+            result = ACTOR_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_USE_CASE:
         {
-            utf8stringbuf_copy_str( out_name, USECASE_NAMES[cycle_names&0x07] );
+            result = USECASE_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_SUBSYSTEM:
         {
-            utf8stringbuf_copy_str( out_name, BOUNDARIES_NAMES[cycle_names&0x07] );
+            result = BOUNDARIES_NAMES[cycle_names&0x07];
         }
         break;
 
@@ -630,7 +608,7 @@ void gui_sketch_object_creator_private_propose_classifier_name( gui_sketch_objec
         case DATA_CLASSIFIER_TYPE_DYN_ACCEPT_TIME_EVENT:
         case DATA_CLASSIFIER_TYPE_DYN_SEND_SIGNAL:
         {
-            utf8stringbuf_copy_str( out_name, ACTIVITY_NAMES[cycle_names&0x07] );
+            result = ACTIVITY_NAMES[cycle_names&0x07];
         }
         break;
 
@@ -638,97 +616,107 @@ void gui_sketch_object_creator_private_propose_classifier_name( gui_sketch_objec
         case DATA_CLASSIFIER_TYPE_DYN_SHALLOW_HISTORY:
         case DATA_CLASSIFIER_TYPE_DYN_DEEP_HISTORY:
         {
-            utf8stringbuf_copy_str( out_name, STATE_NAMES[cycle_names&0x07] );
+            result = STATE_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_DIAGRAM_REFERENCE:
         {
-            utf8stringbuf_copy_str( out_name, DIAGREF_NAMES[cycle_names&0x07] );
+            result = DIAGREF_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_NODE:
         {
-            utf8stringbuf_copy_str( out_name, BLOCK_NAMES[cycle_names&0x07] );
+            result = BLOCK_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_COMPONENT:  /* and */
         {
-            utf8stringbuf_copy_str( out_name, COMPONENT_NAMES[cycle_names&0x07] );
+            result = COMPONENT_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_PART:
         {
-            utf8stringbuf_copy_str( out_name, COMPONENT_NAMES[cycle_names&0x07] );
+            result = COMPONENT_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_ARTIFACT:
         {
-            utf8stringbuf_copy_str( out_name, ARTIFACT_NAMES[cycle_names&0x07] );
+            result = ARTIFACT_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_INTERFACE:  /* and */
         {
-            utf8stringbuf_copy_str( out_name, IF_NAMES[cycle_names&0x07] );
+            result = IF_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_CLASS:  /* and */
         {
-            utf8stringbuf_copy_str( out_name, CLASS_NAMES[cycle_names&0x07] );
+            result = CLASS_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_OBJECT:  /* and */
         {
-            utf8stringbuf_copy_str( out_name, CLASS_NAMES[cycle_names&0x07] );
+            result = CLASS_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_PACKAGE:
         {
-            utf8stringbuf_copy_str( out_name, PACKAGE_NAMES[cycle_names&0x07] );
+            result = PACKAGE_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_COMMENT:
         {
-            utf8stringbuf_copy_str( out_name, NOTE_NAMES[cycle_names&0x07] );
+            result = NOTE_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_CLASSIFIER_TYPE_STEREOTYPE:
+        case DATA_CLASSIFIER_TYPE_IMAGE:
         {
-            utf8stringbuf_copy_str( out_name, STEREOTYPE_NAMES[cycle_names&0x07] );
+            result = STEREOTYPE_NAMES[cycle_names&0x07];
         }
         break;
 
         default:
         {
             U8_LOG_ERROR("data_classifier_type_t out of range in gui_sketch_object_creator_private_propose_classifier_name");
-            utf8stringbuf_clear( out_name );
+            result = "";
         }
         break;
     }
+
+    return result;
 }
 
-void gui_sketch_object_creator_private_propose_feature_name( gui_sketch_object_creator_t *this_,
-                                                             data_feature_type_t f_type,
-                                                             utf8stringbuf_t out_name )
+const char* gui_sketch_object_creator_private_propose_feature_name( gui_sketch_object_creator_t *this_, data_feature_type_t f_type )
 {
+    const char* result = "";
+
     static int cycle_names = 0;
-    static char *(PROPERTY_NAMES[8]) = {"new_state","new_run_mode","new_error_code","new_color","new_name","new_type","new_size","new_weight"};
-    static char *(OPERATION_NAMES[8]) = {"new_start","new_stop","new_pause","new_resume","new_get_state","new_handle_event","new_set_color","new_is_valid"};
-    static char *(PORT_NAMES[8]) = {"new_in_a","new_in_b","new_in_c","new_out_a","new_out_b","new_out_c","new_out_error","new_in_reset"};
-    static char *(IO_PORT_NAMES[8]) = {"new_order","new_item","new_error","new_report","new_audio_file","new_video_file","new_plan","new_status"};
-    static char *(IF_NAMES[8]) = {"New Auth_IF","New Log_IF","New Trace_IF","New Update_IF","New Sync_IF","New Link_IF","New Alive_IF","New Power_IF"};
-    static char *(ENTRY_NAMES[8]) = {"new_again","new_first_time","new_error_case","new_std_entry","new_retries_exceeded","new_debug","new_rookie_mode","new_last_try"};
-    static char *(EXIT_NAMES[8]) = {"new_abort","new_std_exit","new_precondition_failed","new_warning","new_error","new_retry","new_ok","new_repair_request"};
+    static const char *const (PROPERTY_NAMES[8])
+        = {"new_state","new_run_mode","new_error_code","new_color","new_name","new_type","new_size","new_weight"};
+    static const char *const (OPERATION_NAMES[8])
+        = {"new_start","new_stop","new_pause","new_resume","new_get_state","new_handle_event","new_set_color","new_is_valid"};
+    static const char *const (PORT_NAMES[8])
+        = {"new_in_a","new_in_b","new_in_c","new_out_a","new_out_b","new_out_c","new_out_error","new_in_reset"};
+    static const char *const (IO_PORT_NAMES[8])
+        = {"new_order","new_item","new_error","new_report","new_audio_file","new_video_file","new_plan","new_status"};
+    static const char *const (IF_NAMES[8])
+        = {"New Auth_IF","New Log_IF","New Trace_IF","New Update_IF","New Sync_IF","New Link_IF","New Alive_IF","New Power_IF"};
+    static const char *const (ENTRY_NAMES[8])
+        = {"new_again","new_first_time","new_error_case","new_std_entry","new_retries_exceeded","new_debug","new_rookie_mode","new_last_try"};
+    static const char *const (EXIT_NAMES[8])
+        = {"new_abort","new_std_exit","new_precondition_failed","new_warning","new_error","new_retry","new_ok","new_repair_request"};
 
     cycle_names ++;
 
@@ -737,66 +725,68 @@ void gui_sketch_object_creator_private_propose_feature_name( gui_sketch_object_c
         case DATA_FEATURE_TYPE_PROPERTY:
         case DATA_FEATURE_TYPE_TAGGED_VALUE:
         {
-            utf8stringbuf_copy_str( out_name, PROPERTY_NAMES[cycle_names&0x07] );
+            result = PROPERTY_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_FEATURE_TYPE_OPERATION:
         {
-            utf8stringbuf_copy_str( out_name, OPERATION_NAMES[cycle_names&0x07] );
+            result = OPERATION_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_FEATURE_TYPE_PORT:
         {
-            utf8stringbuf_copy_str( out_name, PORT_NAMES[cycle_names&0x07] );
+            result = PORT_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_FEATURE_TYPE_LIFELINE:
         {
-            utf8stringbuf_clear( out_name );
+            result = "";
         }
         break;
 
         case DATA_FEATURE_TYPE_PROVIDED_INTERFACE:
         {
-            utf8stringbuf_copy_str( out_name, IF_NAMES[cycle_names&0x07] );
+            result = IF_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_FEATURE_TYPE_REQUIRED_INTERFACE:
         {
-            utf8stringbuf_copy_str( out_name, IF_NAMES[cycle_names&0x07] );
+            result = IF_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_FEATURE_TYPE_IN_PORT_PIN:
         case DATA_FEATURE_TYPE_OUT_PORT_PIN:
         {
-            utf8stringbuf_copy_str( out_name, IO_PORT_NAMES[cycle_names&0x07] );
+            result = IO_PORT_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_FEATURE_TYPE_ENTRY:
         {
-            utf8stringbuf_copy_str( out_name, ENTRY_NAMES[cycle_names&0x07] );
+            result = ENTRY_NAMES[cycle_names&0x07];
         }
         break;
 
         case DATA_FEATURE_TYPE_EXIT:
         {
-            utf8stringbuf_copy_str( out_name, EXIT_NAMES[cycle_names&0x07] );
+            result = EXIT_NAMES[cycle_names&0x07];
         }
         break;
 
         default:
         {
             U8_LOG_ERROR("data_feature_type_t out of range in gui_sketch_object_creator_private_propose_feature_name");
-            utf8stringbuf_clear( out_name );
+            result = "";
         }
         break;
     }
+
+    return result;
 }
 
 
