@@ -20,9 +20,11 @@
 #include "storage/data_database.h"
 #include "pencil_diagram_maker.h"
 #include "set/data_visible_set.h"
+#include "set/data_profile_part.h"
 #include "set/data_stat.h"
 #include "geometry/geometry_rectangle.h"
 #include "utf8stringbuf/utf8stringbuf.h"
+#include "u8/u8_error.h"
 #include <gtk/gtk.h>
 
 /*!
@@ -36,6 +38,7 @@ struct io_exporter_struct {
 
     /* temporary member attributes, only valid during exporting */
     data_visible_set_t temp_input_data;  /*!< buffer to cache the diagram data */
+    data_profile_part_t temp_profile;  /*!< caches the stereotypes referenced from the current diagram */
 
     image_format_writer_t temp_image_format_exporter;  /*!< exports single diagram images to one given file */
     io_export_model_traversal_t temp_model_traversal;  /*!< own instance of a model_traversal for text export */
@@ -76,26 +79,26 @@ void io_exporter_destroy( io_exporter_t *this_ );
  *  \param target_folder path name to a folder where to store the images
  *  \param document_file_path path to the central/main document file
  *  \param io_export_stat pointer to already initialized statistics object where export statistics are collected
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_export_files( io_exporter_t *this_,
-                              io_file_format_t export_type,
-                              const char *target_folder,
-                              const char *document_file_path,
-                              data_stat_t *io_export_stat
-                            );
+u8_error_t io_exporter_export_files( io_exporter_t *this_,
+                                     io_file_format_t export_type,
+                                     const char *target_folder,
+                                     const char *document_file_path,
+                                     data_stat_t *io_export_stat
+                                   );
 
 /*!
  *  \brief extracts the base file name without extension from the given path
  *  \param this_ pointer to own object attributes
  *  \param path path name to a file from which to extract the base file name
  *  \param out_base_filename name of the file - without path and without filename-suffix
- *  \return 0 in case of success, -1 otherwise, e.g if filename is empty or too long
+ *  \return U8_ERROR_NONE in case of success, e.g if filename is empty or too long
  */
-int io_exporter_private_get_filename( io_exporter_t *this_,
-                                      const char* path,
-                                      utf8stringbuf_t out_base_filename
-                                    );
+u8_error_t io_exporter_private_get_filename( io_exporter_t *this_,
+                                             const char* path,
+                                             utf8stringbuf_t out_base_filename
+                                           );
 
 /*!
  *  \brief renders diagrams and exports these to picture (or text) files, does recursion for child diagrams
@@ -105,15 +108,15 @@ int io_exporter_private_get_filename( io_exporter_t *this_,
  *  \param export_type image file format
  *  \param target_folder path name to a folder where to store the images
  *  \param io_export_stat pointer to statistics object where export statistics are collected
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_private_export_image_files( io_exporter_t *this_,
-                                            data_id_t diagram_id,
-                                            uint32_t max_recursion,
-                                            io_file_format_t export_type,
-                                            const char *target_folder,
-                                            data_stat_t *io_export_stat
-                                          );
+u8_error_t io_exporter_private_export_image_files( io_exporter_t *this_,
+                                                   data_id_t diagram_id,
+                                                   uint32_t max_recursion,
+                                                   io_file_format_t export_type,
+                                                   const char *target_folder,
+                                                   data_stat_t *io_export_stat
+                                                 );
 
 /*!
  *  \brief renders one diagram and exports it to a picture (or text) file
@@ -122,14 +125,14 @@ int io_exporter_private_export_image_files( io_exporter_t *this_,
  *  \param export_type image file format
  *  \param file_path path name to the export file
  *  \param io_export_stat pointer to statistics object where export statistics are collected
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_export_image_file( io_exporter_t *this_,
-                                   data_id_t diagram_id,
-                                   io_file_format_t export_type,
-                                   const char *file_path,
-                                   data_stat_t *io_export_stat
-                                 );
+u8_error_t io_exporter_export_image_file( io_exporter_t *this_,
+                                          data_id_t diagram_id,
+                                          io_file_format_t export_type,
+                                          const char *file_path,
+                                          data_stat_t *io_export_stat
+                                        );
 
 /*!
  *  \brief creates a document file
@@ -138,14 +141,14 @@ int io_exporter_export_image_file( io_exporter_t *this_,
  *  \param target_folder directory where to write the document to
  *  \param document_file_name name of the central/main document file (without filename-suffix)
  *  \param io_export_stat pointer to statistics object where export statistics are collected
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_private_export_document_file( io_exporter_t *this_,
-                                              io_file_format_t export_type,
-                                              const char *target_folder,
-                                              const char *document_file_name,
-                                              data_stat_t *io_export_stat
-                                            );
+u8_error_t io_exporter_private_export_document_file( io_exporter_t *this_,
+                                                     io_file_format_t export_type,
+                                                     const char *target_folder,
+                                                     const char *document_file_name,
+                                                     data_stat_t *io_export_stat
+                                                   );
 
 /*!
  *  \brief creates a document file
@@ -154,14 +157,14 @@ int io_exporter_private_export_document_file( io_exporter_t *this_,
  *  \param document_title title of the document to export
  *  \param file_path path name to the export file
  *  \param io_export_stat pointer to statistics object where export statistics are collected
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_export_document_file( io_exporter_t *this_,
-                                      io_file_format_t export_type,
-                                      const char *document_title,
-                                      const char *file_path,
-                                      data_stat_t *io_export_stat
-                                    );
+u8_error_t io_exporter_export_document_file( io_exporter_t *this_,
+                                             io_file_format_t export_type,
+                                             const char *document_title,
+                                             const char *file_path,
+                                             data_stat_t *io_export_stat
+                                           );
 
 /*!
  *  \brief creates a document part
@@ -169,13 +172,13 @@ int io_exporter_export_document_file( io_exporter_t *this_,
  *  \param diagram_id id of the diagram to export; DATA_ROW_ID_VOID to export all root diagrams
  *  \param max_recursion if greater than 0 and children exist, this function calls itself recursively
  *  \param io_export_stat pointer to statistics object where export statistics are collected
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_private_export_document_part( io_exporter_t *this_,
-                                              data_id_t diagram_id,
-                                              uint32_t max_recursion,
-                                              data_stat_t *io_export_stat
-                                            );
+u8_error_t io_exporter_private_export_document_part( io_exporter_t *this_,
+                                                     data_id_t diagram_id,
+                                                     uint32_t max_recursion,
+                                                     data_stat_t *io_export_stat
+                                                   );
 
 /*!
  *  \brief creates a table of contents
@@ -183,9 +186,9 @@ int io_exporter_private_export_document_part( io_exporter_t *this_,
  *  \param diagram_id id of the diagram to export; DATA_ROW_ID_VOID to export all root diagrams
  *  \param max_recursion if greater than 0 and children exist, this function calls itself recursively
  *  \param format_writer writer to format the data and stream it out to a file
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
+u8_error_t io_exporter_private_export_table_of_contents( io_exporter_t *this_,
                                                   data_id_t diagram_id,
                                                   uint32_t max_recursion,
                                                   xhtml_element_writer_t *format_writer
@@ -196,12 +199,12 @@ int io_exporter_private_export_table_of_contents( io_exporter_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the diagam
  *  \param filename filename stringbuffer to which to write the filename
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int io_exporter_private_get_filename_for_diagram( io_exporter_t *this_,
-                                                  data_id_t diagram_id,
-                                                  utf8stringbuf_t filename
-                                                );
+u8_error_t io_exporter_private_get_filename_for_diagram( io_exporter_t *this_,
+                                                         data_id_t diagram_id,
+                                                         utf8stringbuf_t filename
+                                                       );
 
 /*!
  *  \brief appends all characters that are valid within a filename to filename
