@@ -24,6 +24,7 @@
 #include "data_diagramelement.h"
 #include "set/data_stat.h"
 #include "u8stream/universal_output_stream.h"
+#include "u8/u8_error.h"
 
 /*!
  *  \brief object (vmt+data) of a json_element_writer_t.
@@ -90,9 +91,9 @@ void json_element_writer_set_mode( json_element_writer_t *this_, json_writer_pas
  *
  *  \param this_ pointer to own object attributes
  *  \param document_title title of the document
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_write_header( json_element_writer_t *this_, const char *document_title );
+u8_error_t json_element_writer_write_header( json_element_writer_t *this_, const char *document_title );
 
 /*!
  *  \brief writes the start of the main section
@@ -101,9 +102,9 @@ int json_element_writer_write_header( json_element_writer_t *this_, const char *
  *
  *  \param this_ pointer to own object attributes
  *  \param document_title title of the document
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_start_main( json_element_writer_t *this_, const char *document_title );
+u8_error_t json_element_writer_start_main( json_element_writer_t *this_, const char *document_title );
 
 /*!
  *  \brief checks if a hosting parent classifier may nest a child classifier
@@ -139,12 +140,12 @@ bool json_element_writer_can_classifier_nest_relationship( json_element_writer_t
  *  \param this_ pointer to own object attributes
  *  \param host_type type of the hosting parent classifier, needed for xmi export, DATA_CLASSIFIER_TYPE_VOID if toplevel
  *  \param classifier_ptr pointer to classifier that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_start_classifier( json_element_writer_t *this_,
-                                          data_classifier_type_t host_type,
-                                          const data_classifier_t *classifier_ptr
-                                        );
+u8_error_t json_element_writer_start_classifier( json_element_writer_t *this_,
+                                                 data_classifier_type_t host_type,
+                                                 const data_classifier_t *classifier_ptr
+                                               );
 
 /*!
  *  \brief writes contents of a classifier
@@ -152,12 +153,12 @@ int json_element_writer_start_classifier( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param host_type type of the hosting parent classifier, needed for xmi export, DATA_CLASSIFIER_TYPE_VOID if toplevel
  *  \param classifier_ptr pointer to classifier that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_assemble_classifier( json_element_writer_t *this_,
-                                             data_classifier_type_t host_type,
-                                             const data_classifier_t *classifier_ptr
-                                           );
+u8_error_t json_element_writer_assemble_classifier( json_element_writer_t *this_,
+                                                    data_classifier_type_t host_type,
+                                                    const data_classifier_t *classifier_ptr
+                                                  );
 
 /*!
  *  \brief writes a classifier end-element
@@ -167,12 +168,12 @@ int json_element_writer_assemble_classifier( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param host_type type of the hosting parent classifier, needed for xmi export, DATA_CLASSIFIER_TYPE_VOID if toplevel
  *  \param classifier_ptr pointer to classifier that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_end_classifier( json_element_writer_t *this_,
-                                        data_classifier_type_t host_type,
-                                        const data_classifier_t *classifier_ptr
-                                      );
+u8_error_t json_element_writer_end_classifier( json_element_writer_t *this_,
+                                               data_classifier_type_t host_type,
+                                               const data_classifier_t *classifier_ptr
+                                             );
 
 /*!
  *  \brief writes a feature start-element
@@ -180,12 +181,12 @@ int json_element_writer_end_classifier( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param parent_type type of the owning parent classifier
  *  \param feature_ptr pointer to feature that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_start_feature( json_element_writer_t *this_,
-                                       data_classifier_type_t parent_type,
-                                       const data_feature_t *feature_ptr
-                                     );
+u8_error_t json_element_writer_start_feature( json_element_writer_t *this_,
+                                              data_classifier_type_t parent_type,
+                                              const data_feature_t *feature_ptr
+                                            );
 
 /*!
  *  \brief writes constents of a a feature
@@ -193,12 +194,12 @@ int json_element_writer_start_feature( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param parent the owning parent classifier
  *  \param feature_ptr pointer to feature that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_assemble_feature( json_element_writer_t *this_,
-                                          const data_classifier_t *parent,
-                                          const data_feature_t *feature_ptr
-                                        );
+u8_error_t json_element_writer_assemble_feature( json_element_writer_t *this_,
+                                                 const data_classifier_t *parent,
+                                                 const data_feature_t *feature_ptr
+                                               );
 
 /*!
  *  \brief writes a feature end-element
@@ -206,12 +207,12 @@ int json_element_writer_assemble_feature( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param parent_type type of the owning parent classifier
  *  \param feature_ptr pointer to feature that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_end_feature( json_element_writer_t *this_,
-                                     data_classifier_type_t parent_type,
-                                     const data_feature_t *feature_ptr
-                                   );
+u8_error_t json_element_writer_end_feature( json_element_writer_t *this_,
+                                            data_classifier_type_t parent_type,
+                                            const data_feature_t *feature_ptr
+                                          );
 
 /*!
  *  \brief starts a relationship
@@ -219,12 +220,12 @@ int json_element_writer_end_feature( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param host_type type of the hosting parent classifier, needed for xmi export
  *  \param relation_ptr pointer to relationship that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_start_relationship( json_element_writer_t *this_,
-                                            data_classifier_type_t host_type,
-                                            const data_relationship_t *relation_ptr
-                                          );
+u8_error_t json_element_writer_start_relationship( json_element_writer_t *this_,
+                                                   data_classifier_type_t host_type,
+                                                   const data_relationship_t *relation_ptr
+                                                 );
 
 /*!
  *  \brief writes the contents of a relationship
@@ -236,16 +237,16 @@ int json_element_writer_start_relationship( json_element_writer_t *this_,
  *  \param from_f the feature at source end; NULL or !is_valid() if no feature specified
  *  \param to_c the classifier at target end
  *  \param to_f the feature at target end; NULL or !is_valid() if no feature specified
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_assemble_relationship( json_element_writer_t *this_,
-                                               const data_classifier_t *host,
-                                               const data_relationship_t *relation_ptr,
-                                               const data_classifier_t *from_c,
-                                               const data_feature_t *from_f,
-                                               const data_classifier_t *to_c,
-                                               const data_feature_t *to_f
-                                             );
+u8_error_t json_element_writer_assemble_relationship( json_element_writer_t *this_,
+                                                      const data_classifier_t *host,
+                                                      const data_relationship_t *relation_ptr,
+                                                      const data_classifier_t *from_c,
+                                                      const data_feature_t *from_f,
+                                                      const data_classifier_t *to_c,
+                                                      const data_feature_t *to_f
+                                                    );
 
 /*!
  *  \brief ends a relationship
@@ -253,12 +254,12 @@ int json_element_writer_assemble_relationship( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param host_type type of the hosting parent classifier, needed for xmi export
  *  \param relation_ptr pointer to relationship that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_end_relationship( json_element_writer_t *this_,
-                                          data_classifier_type_t host_type,
-                                          const data_relationship_t *relation_ptr
-                                        );
+u8_error_t json_element_writer_end_relationship( json_element_writer_t *this_,
+                                                 data_classifier_type_t host_type,
+                                                 const data_relationship_t *relation_ptr
+                                               );
 
 /*!
  *  \brief writes a diagram start
@@ -267,9 +268,9 @@ int json_element_writer_end_relationship( json_element_writer_t *this_,
  *
  *  \param this_ pointer to own object attributes
  *  \param diag_ptr pointer to diagram that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_start_diagram( json_element_writer_t *this_, const data_diagram_t *diag_ptr );
+u8_error_t json_element_writer_start_diagram( json_element_writer_t *this_, const data_diagram_t *diag_ptr );
 
 /*!
  *  \brief writes a diagram of the document
@@ -278,13 +279,13 @@ int json_element_writer_start_diagram( json_element_writer_t *this_, const data_
  *  \param parent pointer to parent diagram or NULL in case of root
  *  \param diag_ptr pointer to diagram that shall be written
  *  \param diagram_file_base_name filename of the diagram without extension
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_assemble_diagram( json_element_writer_t *this_,
-                                          const data_diagram_t *parent,
-                                          const data_diagram_t *diag_ptr,
-                                          const char *diagram_file_base_name
-                                        );
+u8_error_t json_element_writer_assemble_diagram( json_element_writer_t *this_,
+                                                 const data_diagram_t *parent,
+                                                 const data_diagram_t *diag_ptr,
+                                                 const char *diagram_file_base_name
+                                               );
 
 /*!
  *  \brief ends a diagram
@@ -293,9 +294,9 @@ int json_element_writer_assemble_diagram( json_element_writer_t *this_,
  *
  *  \param this_ pointer to own object attributes
  *  \param diag_ptr pointer to diagram that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_end_diagram_fake( json_element_writer_t *this_, const data_diagram_t *diag_ptr );
+u8_error_t json_element_writer_end_diagram_fake( json_element_writer_t *this_, const data_diagram_t *diag_ptr );
 
 /*!
  *  \brief ends a diagram
@@ -303,9 +304,9 @@ int json_element_writer_end_diagram_fake( json_element_writer_t *this_, const da
  *  This ends a section that contains a diagram and a list of diagramelements (classifier-occurrences)
  *
  *  \param this_ pointer to own object attributes
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_private_end_diagram( json_element_writer_t *this_ );
+u8_error_t json_element_writer_private_end_diagram( json_element_writer_t *this_ );
 
 /*!
  *  \brief writes a diagramelement start-element
@@ -313,12 +314,12 @@ int json_element_writer_private_end_diagram( json_element_writer_t *this_ );
  *  \param this_ pointer to own object attributes
  *  \param parent the hosting parent diagram
  *  \param diagramelement_ptr pointer to diagramelement that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_start_diagramelement( json_element_writer_t *this_,
-                                              const data_diagram_t *parent,
-                                              const data_diagramelement_t *diagramelement_ptr
-                                            );
+u8_error_t json_element_writer_start_diagramelement( json_element_writer_t *this_,
+                                                     const data_diagram_t *parent,
+                                                     const data_diagramelement_t *diagramelement_ptr
+                                                   );
 
 /*!
  *  \brief writes constents of a a diagramelement
@@ -328,14 +329,14 @@ int json_element_writer_start_diagramelement( json_element_writer_t *this_,
  *  \param diagramelement_ptr pointer to diagramelement that shall be written, not NULL
  *  \param occurrence the occurring classifier
  *  \param feat_occur the focused feature of the occurring classifier
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_assemble_diagramelement( json_element_writer_t *this_,
-                                                 const data_diagram_t *parent,
-                                                 const data_diagramelement_t *diagramelement_ptr,
-                                                 const data_classifier_t *occurrence,
-                                                 const data_feature_t *feat_occur
-                                               );
+u8_error_t json_element_writer_assemble_diagramelement( json_element_writer_t *this_,
+                                                        const data_diagram_t *parent,
+                                                        const data_diagramelement_t *diagramelement_ptr,
+                                                        const data_classifier_t *occurrence,
+                                                        const data_feature_t *feat_occur
+                                                      );
 
 /*!
  *  \brief writes a diagramelement end-element
@@ -343,12 +344,12 @@ int json_element_writer_assemble_diagramelement( json_element_writer_t *this_,
  *  \param this_ pointer to own object attributes
  *  \param parent the hosting parent diagram
  *  \param diagramelement_ptr pointer to diagramelement that shall be written, not NULL
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_end_diagramelement( json_element_writer_t *this_,
-                                            const data_diagram_t *parent,
-                                            const data_diagramelement_t *diagramelement_ptr
-                                          );
+u8_error_t json_element_writer_end_diagramelement( json_element_writer_t *this_,
+                                                   const data_diagram_t *parent,
+                                                   const data_diagramelement_t *diagramelement_ptr
+                                                 );
 
 /*!
  *  \brief writes the ending of the main section
@@ -356,17 +357,17 @@ int json_element_writer_end_diagramelement( json_element_writer_t *this_,
  *  This ends a section that contains the main part of the document
  *
  *  \param this_ pointer to own object attributes
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_end_main( json_element_writer_t *this_ );
+u8_error_t json_element_writer_end_main( json_element_writer_t *this_ );
 
 /*!
  *  \brief writes the footer of the document
  *
  *  \param this_ pointer to own object attributes
- *  \return 0 in case of success, -1 otherwise
+ *  \return U8_ERROR_NONE in case of success
  */
-int json_element_writer_write_footer( json_element_writer_t *this_ );
+u8_error_t json_element_writer_write_footer( json_element_writer_t *this_ );
 
 #endif  /* JSON_ELEMENT_WRITER_H */
 
