@@ -14,9 +14,9 @@
 #include "u8/u8_trace.h"
 #include "test_expect.h"
 
-static void set_up(void);
-static void tear_down(void);
-static void iterate_types_on_mini_model(void);
+static test_fixture_t * set_up();
+static void tear_down( test_fixture_t *test_env );
+static test_case_result_t iterate_types_on_mini_model( test_fixture_t *test_env );
 
 /*!
  *  \brief helper function to initialize the database
@@ -67,7 +67,7 @@ test_suite_t io_export_model_traversal_test_get_suite(void)
     return result;
 }
 
-static void set_up(void)
+static test_fixture_t * set_up()
 {
     data_database_init( &database );
     data_database_open_in_memory( &database );
@@ -78,9 +78,10 @@ static void set_up(void)
                                          &mem_buffer,
                                          sizeof(mem_buffer)
                                        );
+    return NULL;
 }
 
-static void tear_down(void)
+static void tear_down( test_fixture_t *test_env )
 {
     universal_memory_output_stream_destroy( &mem_output_stream );
 
@@ -105,31 +106,33 @@ static void create_mini_model( data_row_id_t * out_root_diagram,
     ctrl_classifier_controller_t *classifier_ctrl;
     classifier_ctrl = ctrl_controller_get_classifier_control_ptr( &controller );
     u8_error_t c_err;
+    test_env_setup_t test_env;
+    test_env_setup_init( &test_env, &controller );
 
-    *out_root_diagram = test_env_setup_data_create_diagram( DATA_ROW_ID_VOID, "root diag", &controller );
+    *out_root_diagram = test_env_setup_data_create_diagram( &test_env, DATA_ROW_ID_VOID, "root diag" );
 
-    *out_from_classifier_parent = test_env_setup_data_create_classifier( "from parent", &controller );
-    test_env_setup_data_create_diagramelement( *out_root_diagram, *out_from_classifier_parent, DATA_ROW_ID_VOID, &controller );
+    *out_from_classifier_parent = test_env_setup_data_create_classifier( &test_env, "from parent" );
+    test_env_setup_data_create_diagramelement( &test_env, *out_root_diagram, *out_from_classifier_parent, DATA_ROW_ID_VOID );
 
-    *out_from_classifier = test_env_setup_data_create_classifier( "from classifier", &controller );
-    *out_from_feature = test_env_setup_data_create_feature( *out_from_classifier, "from feature", &controller );
-    test_env_setup_data_create_diagramelement( *out_root_diagram, *out_from_classifier, *out_from_feature, &controller );
+    *out_from_classifier = test_env_setup_data_create_classifier( &test_env, "from classifier" );
+    *out_from_feature = test_env_setup_data_create_feature( &test_env, *out_from_classifier, "from feature" );
+    test_env_setup_data_create_diagramelement( &test_env, *out_root_diagram, *out_from_classifier, *out_from_feature );
 
-    *out_to_classifier_parent = test_env_setup_data_create_classifier( "to parent", &controller );
-    test_env_setup_data_create_diagramelement( *out_root_diagram, *out_to_classifier_parent, DATA_ROW_ID_VOID, &controller );
+    *out_to_classifier_parent = test_env_setup_data_create_classifier( &test_env, "to parent" );
+    test_env_setup_data_create_diagramelement( &test_env, *out_root_diagram, *out_to_classifier_parent, DATA_ROW_ID_VOID );
 
-    *out_to_classifier = test_env_setup_data_create_classifier( "to classifier", &controller );
-    *out_to_feature = test_env_setup_data_create_feature( *out_to_classifier, "to feature", &controller );
-    test_env_setup_data_create_diagramelement( *out_root_diagram, *out_to_classifier, *out_to_feature, &controller );
+    *out_to_classifier = test_env_setup_data_create_classifier( &test_env, "to classifier" );
+    *out_to_feature = test_env_setup_data_create_feature( &test_env, *out_to_classifier, "to feature" );
+    test_env_setup_data_create_diagramelement( &test_env, *out_root_diagram, *out_to_classifier, *out_to_feature );
 
     /* from child has parent */
     {
-        data_row_id_t from_parent_rel_id = test_env_setup_data_create_relationship( *out_from_classifier_parent,
+        data_row_id_t from_parent_rel_id = test_env_setup_data_create_relationship( &test_env,
+                                                                                    *out_from_classifier_parent,
                                                                                     DATA_ROW_ID_VOID,
                                                                                     *out_from_classifier,
                                                                                     DATA_ROW_ID_VOID,
-                                                                                    "from child rel",
-                                                                                    &controller
+                                                                                    "from child rel"
                                                                                   );
         c_err = ctrl_classifier_controller_update_relationship_main_type ( classifier_ctrl,
                                                                            from_parent_rel_id,
@@ -140,12 +143,12 @@ static void create_mini_model( data_row_id_t * out_root_diagram,
 
     /* to child has parent */
     {
-        data_row_id_t to_parent_rel_id = test_env_setup_data_create_relationship( *out_to_classifier_parent,
+        data_row_id_t to_parent_rel_id = test_env_setup_data_create_relationship( &test_env,
+                                                                                  *out_to_classifier_parent,
                                                                                   DATA_ROW_ID_VOID,
                                                                                   *out_to_classifier,
                                                                                   DATA_ROW_ID_VOID,
-                                                                                  "to child rel",
-                                                                                  &controller
+                                                                                  "to child rel"
                                                                                 );
         c_err = ctrl_classifier_controller_update_relationship_main_type ( classifier_ctrl,
                                                                            to_parent_rel_id,
@@ -154,34 +157,36 @@ static void create_mini_model( data_row_id_t * out_root_diagram,
         TEST_ENVIRONMENT_ASSERT( U8_ERROR_NONE == c_err );
     }
 
-    *out_relation_clas_clas = test_env_setup_data_create_relationship( *out_from_classifier_parent,
+    *out_relation_clas_clas = test_env_setup_data_create_relationship( &test_env,
+                                                                       *out_from_classifier_parent,
                                                                        DATA_ROW_ID_VOID,
                                                                        *out_to_classifier,
                                                                        DATA_ROW_ID_VOID,
-                                                                       "from classifier to classifier",
-                                                                       &controller
+                                                                       "from classifier to classifier"
                                                                      );
-    *out_relation_clas_feat = test_env_setup_data_create_relationship( *out_from_classifier_parent,
+    *out_relation_clas_feat = test_env_setup_data_create_relationship( &test_env,
+                                                                       *out_from_classifier_parent,
                                                                        DATA_ROW_ID_VOID,
                                                                        *out_to_classifier,
                                                                        *out_to_feature,
-                                                                       "from classifier to feature",
-                                                                       &controller
+                                                                       "from classifier to feature"
                                                                      );
-    *out_relation_feat_clas = test_env_setup_data_create_relationship( *out_from_classifier_parent,
+    *out_relation_feat_clas = test_env_setup_data_create_relationship( &test_env,
+                                                                       *out_from_classifier_parent,
                                                                        *out_from_feature,
                                                                        *out_to_classifier,
                                                                        DATA_ROW_ID_VOID,
-                                                                       "from feature to classifier",
-                                                                       &controller
+                                                                       "from feature to classifier"
                                                                      );
-    *out_relation_feat_feat = test_env_setup_data_create_relationship( *out_from_classifier_parent,
+    *out_relation_feat_feat = test_env_setup_data_create_relationship( &test_env,
+                                                                       *out_from_classifier_parent,
                                                                        *out_from_feature,
                                                                        *out_to_classifier,
                                                                        *out_to_feature,
-                                                                       "from feature to feature",
-                                                                       &controller
+                                                                       "from feature to feature"
                                                                      );
+
+    test_env_setup_destroy( &test_env );
 }
 
 enum io_export_model_traversal_test_future_enum {
@@ -255,7 +260,7 @@ static const data_relationship_type_t relationship_types[]
     (data_relationship_type_t) IO_EXPORT_MODEL_TRAVERSAL_TEST_FUTURE_TYPE,  /* downwards compatibility check */
 };
 
-static void iterate_types_on_mini_model(void)
+static test_case_result_t iterate_types_on_mini_model( test_fixture_t *test_env )
 {
     /* fill database with mini model */
     data_row_id_t from_classifier_parent;
@@ -408,6 +413,7 @@ static void iterate_types_on_mini_model(void)
             }
         }
     }
+    return TEST_CASE_RESULT_OK;
 }
 
 
