@@ -13,18 +13,18 @@
 #include "u8/u8_trace.h"
 #include "test_expect.h"
 
-static void set_up(void);
-static void tear_down(void);
-static void insert_invalid_json(void);
-static void insert_invalid_parent_diag(void);
-static void insert_empty_set(void);
-static void insert_new_classifier_to_existing_diagram(void);
-static void insert_new_classifier_to_new_diagram(void);
-static void insert_existing_feature_to_other_classifier(void);
-static void insert_existing_classifier_to_new_diagram(void);
-static void insert_unconditional_relationships(void);
-static void insert_relationships_to_non_scenario(void);
-static void insert_scenario_relationships_to_scenario(void);
+static test_fixture_t * set_up();
+static void tear_down( test_fixture_t *test_env );
+static test_case_result_t insert_invalid_json( test_fixture_t *test_env );
+static test_case_result_t insert_invalid_parent_diag( test_fixture_t *test_env );
+static test_case_result_t insert_empty_set( test_fixture_t *test_env );
+static test_case_result_t insert_new_classifier_to_existing_diagram( test_fixture_t *test_env );
+static test_case_result_t insert_new_classifier_to_new_diagram( test_fixture_t *test_env );
+static test_case_result_t insert_existing_feature_to_other_classifier( test_fixture_t *test_env );
+static test_case_result_t insert_existing_classifier_to_new_diagram( test_fixture_t *test_env );
+static test_case_result_t insert_unconditional_relationships( test_fixture_t *test_env );
+static test_case_result_t insert_relationships_to_non_scenario( test_fixture_t *test_env );
+static test_case_result_t insert_scenario_relationships_to_scenario( test_fixture_t *test_env );
 
 static data_row_id_t create_root_diag();  /* helper function */
 
@@ -60,7 +60,7 @@ test_suite_t io_importer_test_get_suite(void)
     return result;
 }
 
-static void set_up(void)
+static test_fixture_t * set_up()
 {
     data_database_init( &database );
     data_database_open_in_memory( &database );
@@ -68,9 +68,10 @@ static void set_up(void)
     data_database_reader_init( &db_reader, &database );
 
     ctrl_controller_init( &controller, &database );
+    return NULL;
 }
 
-static void tear_down(void)
+static void tear_down( test_fixture_t *test_env )
 {
     ctrl_controller_destroy( &controller );
 
@@ -116,6 +117,7 @@ static data_row_id_t create_root_diag()
     data_diagram_destroy ( &root_diagram );
 
     return root_diag_id;
+    return TEST_CASE_RESULT_OK;
 }
 
 static const char *const test_json_own_diagram =
@@ -285,7 +287,7 @@ static const char *const test_json_no_diag =
     "  ]\n"
     "}\n";
 
-static void insert_invalid_json(void)
+static test_case_result_t insert_invalid_json( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -307,7 +309,7 @@ static void insert_invalid_json(void)
     TEST_EXPECT_EQUAL_INT( data_stat_get_total_count( &stat ), 0 );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_PARSER_STRUCTURE, u8_error_info_get_error( &read_line ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_line ) );
-    TEST_EXPECT_EQUAL_INT( 2, u8_error_info_get_position( &read_line ) );
+    TEST_EXPECT_EQUAL_INT( 2, u8_error_info_get_line( &read_line ) );
 
     /* error happens at char 24 according to the log */
     /* but this happens in json_element_reader_get_type_of_next_element which does not advance the read pos */
@@ -323,13 +325,14 @@ static void insert_invalid_json(void)
     TEST_EXPECT_EQUAL_INT( data_stat_get_total_count( &stat ), 0 );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_PARSER_STRUCTURE, u8_error_info_get_error( &read_line ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_line ) );
-    TEST_EXPECT_EQUAL_INT( 2, u8_error_info_get_position( &read_line ) );
+    TEST_EXPECT_EQUAL_INT( 2, u8_error_info_get_line( &read_line ) );
 
     data_stat_destroy(&stat);
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void insert_invalid_parent_diag(void)
+static test_case_result_t insert_invalid_parent_diag( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -350,13 +353,14 @@ static void insert_invalid_parent_diag(void)
     TEST_EXPECT_EQUAL_INT( data_stat_get_total_count( &stat ), 0 );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_FOCUS_EMPTY, u8_error_info_get_error( &read_line ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_line ) );
-    TEST_EXPECT_EQUAL_INT( 20, u8_error_info_get_position( &read_line ) );
+    TEST_EXPECT_EQUAL_INT( 20, u8_error_info_get_line( &read_line ) );
 
     data_stat_destroy(&stat);
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void insert_empty_set(void)
+static test_case_result_t insert_empty_set( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -378,13 +382,14 @@ static void insert_empty_set(void)
     TEST_EXPECT_EQUAL_INT( data_stat_get_total_count( &stat ), 0 );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_line ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_line ) );
-    TEST_EXPECT_EQUAL_INT( 2, u8_error_info_get_position( &read_line ) );
+    TEST_EXPECT_EQUAL_INT( 2, u8_error_info_get_line( &read_line ) );
 
     data_stat_destroy(&stat);
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void insert_new_classifier_to_existing_diagram(void)
+static test_case_result_t insert_new_classifier_to_existing_diagram( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -411,13 +416,14 @@ static void insert_new_classifier_to_existing_diagram(void)
     TEST_EXPECT_EQUAL_INT( 4, data_stat_get_total_count( &stat ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_VALUE_OUT_OF_RANGE, u8_error_info_get_error( &read_pos ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-    TEST_EXPECT_EQUAL_INT( 62, u8_error_info_get_position( &read_pos ) );
+    TEST_EXPECT_EQUAL_INT( 62, u8_error_info_get_line( &read_pos ) );
 
     data_stat_destroy(&stat);
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void insert_new_classifier_to_new_diagram(void)
+static test_case_result_t insert_new_classifier_to_new_diagram( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -446,13 +452,14 @@ static void insert_new_classifier_to_new_diagram(void)
     TEST_EXPECT_EQUAL_INT( 7, data_stat_get_total_count( &stat ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-    TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_position( &read_pos ) );
+    TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_line( &read_pos ) );
 
     data_stat_destroy(&stat);
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void insert_existing_feature_to_other_classifier(void)
+static test_case_result_t insert_existing_feature_to_other_classifier( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -474,7 +481,7 @@ static void insert_existing_feature_to_other_classifier(void)
         TEST_EXPECT_EQUAL_INT( 4, data_stat_get_total_count( &stat ) );  /* as in test case insert_new_classifier_to_existing_diagram */
         TEST_EXPECT_EQUAL_INT( U8_ERROR_VALUE_OUT_OF_RANGE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 62, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 62, u8_error_info_get_line( &read_pos ) );
 
         data_stat_destroy(&stat);
     }
@@ -502,14 +509,15 @@ static void insert_existing_feature_to_other_classifier(void)
         TEST_EXPECT_EQUAL_INT( 5, data_stat_get_total_count( &stat ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_VALUE_OUT_OF_RANGE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 62, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 62, u8_error_info_get_line( &read_pos ) );
 
         data_stat_destroy(&stat);
     }
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void insert_existing_classifier_to_new_diagram(void)
+static test_case_result_t insert_existing_classifier_to_new_diagram( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -531,7 +539,7 @@ static void insert_existing_classifier_to_new_diagram(void)
         TEST_EXPECT_EQUAL_INT( 7, data_stat_get_total_count( &stat ) );  /* as in test case insert_new_classifier_to_new_diagram */
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_line( &read_pos ) );
 
         data_stat_destroy(&stat);
     }
@@ -561,14 +569,15 @@ static void insert_existing_classifier_to_new_diagram(void)
         TEST_EXPECT_EQUAL_INT( 7, data_stat_get_total_count( &stat ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_line( &read_pos ) );
 
         data_stat_destroy(&stat);
     }
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void insert_unconditional_relationships(void)
+static test_case_result_t insert_unconditional_relationships( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -590,7 +599,7 @@ static void insert_unconditional_relationships(void)
         TEST_EXPECT_EQUAL_INT( 7, data_stat_get_total_count( &stat ) );  /* as in test case insert_new_classifier_to_new_diagram */
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_line( &read_pos ) );
 
         data_stat_destroy(&stat);
     }
@@ -615,11 +624,12 @@ static void insert_unconditional_relationships(void)
         TEST_EXPECT_EQUAL_INT( 5, data_stat_get_total_count( &stat ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 66, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 66, u8_error_info_get_line( &read_pos ) );
 
         data_stat_destroy(&stat);
     }
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
 static const char *const test_non_scenario_relationship =
@@ -699,7 +709,7 @@ static const char *const test_non_scenario_relationship =
     "  ]\n"
     "}\n";
 
-static void insert_relationships_to_non_scenario(void)
+static test_case_result_t insert_relationships_to_non_scenario( test_fixture_t *test_env )
 {
     data_row_id_t root_diag_id = create_root_diag();
 
@@ -726,10 +736,11 @@ static void insert_relationships_to_non_scenario(void)
     TEST_EXPECT_EQUAL_INT( 6, data_stat_get_total_count( &stat ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-    TEST_EXPECT_EQUAL_INT( 76, u8_error_info_get_position( &read_pos ) );
+    TEST_EXPECT_EQUAL_INT( 76, u8_error_info_get_line( &read_pos ) );
 
     data_stat_destroy(&stat);
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
 static const char *const test_json_scenario_self_relation =
@@ -767,7 +778,7 @@ static const char *const test_json_scenario_self_relation =
     "  ]\n"
     "}\n";
 
-static void insert_scenario_relationships_to_scenario(void)
+static test_case_result_t insert_scenario_relationships_to_scenario( test_fixture_t *test_env )
 {
     io_importer_t importer;
     io_importer_init ( &importer, &db_reader, &controller );
@@ -798,7 +809,7 @@ static void insert_scenario_relationships_to_scenario(void)
         TEST_EXPECT_EQUAL_INT( 6, data_stat_get_total_count( &stat ) );  /* 1 less than in insert_new_classifier_to_new_diagram */
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 99, u8_error_info_get_line( &read_pos ) );
 
         universal_memory_input_stream_destroy( &mem_json );
         universal_utf8_writer_destroy( &report );
@@ -826,11 +837,12 @@ static void insert_scenario_relationships_to_scenario(void)
         TEST_EXPECT_EQUAL_INT( 1, data_stat_get_total_count( &stat ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, u8_error_info_get_error( &read_pos ) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_INFO_UNIT_LINE, u8_error_info_get_unit( &read_pos ) );
-        TEST_EXPECT_EQUAL_INT( 34, u8_error_info_get_position( &read_pos ) );
+        TEST_EXPECT_EQUAL_INT( 34, u8_error_info_get_line( &read_pos ) );
 
         data_stat_destroy(&stat);
     }
     io_importer_destroy ( &importer );
+    return TEST_CASE_RESULT_OK;
 }
 
 
