@@ -6,20 +6,22 @@
 #include "unit/data_uuid_test.h"
 #include "unit/data_rules_test.h"
 #include "unit/data_database_listener_test.h"
+#include "integration/data_profile_part_test.h"
 #include "integration/data_database_reader_test.h"
 /* ctrl */
-#include "unit/ctrl_diagram_controller_test.h"
-#include "unit/ctrl_multi_step_changer_test.h"
-#include "unit/ctrl_classifier_controller_test.h"
-#include "unit/ctrl_consistency_checker_test.h"
-#include "unit/ctrl_undo_redo_list_test.h"
-#include "unit/ctrl_diagram_policy_enforcer_test.h"
-#include "unit/ctrl_classifier_policy_enforcer_test.h"
+#include "integration/ctrl_diagram_controller_test.h"
+#include "integration/ctrl_multi_step_changer_test.h"
+#include "integration/ctrl_classifier_controller_test.h"
+#include "integration/ctrl_consistency_checker_test.h"
+#include "integration/ctrl_undo_redo_list_test.h"
+#include "integration/ctrl_diagram_policy_enforcer_test.h"
+#include "integration/ctrl_classifier_policy_enforcer_test.h"
 /* pencil */
 #include "unit/geometry_rectangle_test.h"
 #include "unit/geometry_connector_test.h"
 #include "unit/geometry_non_linear_scale_test.h"
 #include "unit/draw_classifier_contour_test.h"
+#include "unit/draw_stereotype_image_test.h"
 #include "unit/pencil_layout_data_test.h"
 #include "unit/pencil_classifier_composer_test.h"
 #include "integration/pencil_layouter_test.h"
@@ -52,6 +54,7 @@
 /* #include "unit/utf8stringbuf_performance.h" -- performance measurements are not reliable - depend on system config+load */
 #include "unit/utf8stringview_test.h"
 #include "unit/utf8stringviewiterator_test.h"
+#include "unit/utf8stringviewtokenizer_test.h"
 #include "utf8stringbuf/utf8string.h"
 /* TEST_ENVIRONMENT */
 #include "u8/u8_trace.h"
@@ -148,12 +151,14 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, geometry_connector_test_get_suite() );
         test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_suite() );
         test_runner_run_suite( &runner, draw_classifier_contour_test_get_suite() );
+        test_runner_run_suite( &runner, draw_stereotype_image_test_get_suite() );
         test_runner_run_suite( &runner, pencil_classifier_composer_test_get_suite() );
         test_runner_run_suite( &runner, pencil_layout_data_test_get_suite() );
         /* gui */
         /* io */
         test_runner_run_suite( &runner, txt_writer_test_get_suite() );
         test_runner_run_suite( &runner, json_token_reader_test_get_suite() );
+        test_runner_run_suite( &runner, md_filter_test_get_suite() );
         test_runner_run_suite( &runner, io_import_elements_test_get_suite() );
         /* universal */
         test_runner_run_suite( &runner, universal_array_index_sorter_test_get_suite() );
@@ -173,6 +178,7 @@ int main (int argc, char *argv[]) {
         /* test_runner_run_suite( &runner, utf8stringbuf_performance_get_list() ); -- performance measurements are not reliable - depend on system config+load */
         test_runner_run_suite( &runner, utf8stringview_test_get_suite() );
         test_runner_run_suite( &runner, utf8stringviewiterator_test_get_suite() );
+        test_runner_run_suite( &runner, utf8stringviewtokenizer_test_get_suite() );
         test_runner_run_suite( &runner, gui_sketch_nav_tree_test_get_suite() );
     }
 
@@ -181,6 +187,7 @@ int main (int argc, char *argv[]) {
     {
         /* data */
         test_runner_run_suite( &runner, data_database_reader_test_get_suite() );
+        test_runner_run_suite( &runner, data_profile_part_test_get_suite() );
         /* ctrl */
         test_runner_run_suite( &runner, ctrl_multi_step_changer_test_get_suite() );
         test_runner_run_suite( &runner, ctrl_diagram_controller_test_get_suite() );
@@ -196,7 +203,6 @@ int main (int argc, char *argv[]) {
         /* io */
         test_runner_run_suite( &runner, io_data_file_test_get_suite() );
         test_runner_run_suite( &runner, io_importer_test_get_suite() );
-        test_runner_run_suite( &runner, md_filter_test_get_suite() );
         test_runner_run_suite( &runner, io_export_model_traversal_test_get_suite() );
         /* universal */
         /* utf8stringbuf */
