@@ -25,6 +25,9 @@ extern const double DRAW_CLASSIFIER_ICON_COMPONENT_ICON_WIDTH_TO_HEIGHT;
 
 /*!
  *  \brief attributes of the draw symbol functions
+ *
+ *  \note This class is stateless.
+ *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct draw_classifier_icon_struct {
     int dummy;  /*!< This object is a collection of stateless drawing functions */
@@ -46,17 +49,6 @@ static inline void draw_classifier_icon_init( draw_classifier_icon_t *this_ );
  */
 static inline void draw_classifier_icon_destroy( draw_classifier_icon_t *this_ );
 
-/*!
- *  \brief returns true if the classifier is drawn as fixed-size symbol
- *
- *  The following classifier types are fixed-sized symbols: (use-case:) actor, (activity:) start, end, fork, join, timeout, history
- *
- *  \param this_ pointer to own object attributes
- *  \param classifier_type type of the classifier to draw
- *  \return id of the classifier
- */
-static inline bool draw_classifier_icon_is_fix_sized_symbol ( const draw_classifier_icon_t *this_, data_classifier_type_t classifier_type );
-
 /*!
  *  \brief determines the dimensions of the type icon.
  *
@@ -65,7 +57,7 @@ static inline bool draw_classifier_icon_is_fix_sized_symbol ( const draw_classif
  *  \param this_ pointer to own object attributes
  *  \param classifier_type type of the classifier to draw
  *  \param pencil_size set of sizes and colors for drawing lines and text
- *  \return of the icon.
+ *  \return dimension of the icon.
  */
 static inline geometry_dimensions_t draw_classifier_icon_get_icon_dimensions ( const draw_classifier_icon_t *this_,
                                                                                data_classifier_type_t classifier_type,
