@@ -21,6 +21,9 @@
 
 /*!
  *  \brief attributes of the draw label functions
+ *
+ *  \note This class is stateless.
+ *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct draw_classifier_label_struct {
     int dummy;  /*!< This object is a collection of stateless drawing functions */
@@ -47,6 +50,7 @@ static inline void draw_classifier_label_destroy( draw_classifier_label_t *this_
  *
  *  \param this_ pointer to own object attributes
  *  \param visible_classifier the visible_classifier consisting of diagramelement and classifier to draw
+ *  \param with_stereotype false if no stereotype label shall be printed because an image is shown instead
  *  \param proposed_bounds proposed bounds for the text width and height
  *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param font_layout pango layout object to determine the font metrics in the current cairo drawing context
@@ -55,6 +59,7 @@ static inline void draw_classifier_label_destroy( draw_classifier_label_t *this_
  */
 void draw_classifier_label_get_stereotype_and_name_dimensions( const draw_classifier_label_t *this_,
                                                                const data_visible_classifier_t *visible_classifier,
+                                                               bool with_stereotype,
                                                                const geometry_dimensions_t *proposed_bounds,
                                                                const pencil_size_t *pencil_size,
                                                                PangoLayout *font_layout,
@@ -67,6 +72,7 @@ void draw_classifier_label_get_stereotype_and_name_dimensions( const draw_classi
  *
  *  \param this_ pointer to own object attributes
  *  \param visible_classifier the visible_classifier consisting of diagramelement and classifier to draw
+ *  \param with_stereotype false if no stereotype label shall be printed because an image is shown instead
  *  \param label_box the rectangle where to draw to
  *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param font_layout pango layout object to determine the font metrics in the current cairo drawing context
@@ -74,30 +80,13 @@ void draw_classifier_label_get_stereotype_and_name_dimensions( const draw_classi
  */
 void draw_classifier_label_draw_stereotype_and_name( const draw_classifier_label_t *this_,
                                                      const data_visible_classifier_t *visible_classifier,
+                                                     bool with_stereotype,
                                                      const geometry_rectangle_t *label_box,
                                                      const pencil_size_t *pencil_size,
                                                      PangoLayout *font_layout,
                                                      cairo_t *cr
                                                    );
 
-/*!
- *  \brief renders the id of the classifier.
- *
- *  \param this_ pointer to own object attributes
- *  \param visible_classifier the visible_classifier consisting of diagramelement and classifier to draw
- *  \param classifier_bounds the bounding rectangle of the classifier
- *  \param pencil_size set of sizes and colors for drawing lines and text
- *  \param font_layout pango layout object to determine the font metrics in the current cairo drawing context
- *  \param cr the cairo drawing context.
- */
-void draw_classifier_label_draw_id( const draw_classifier_label_t *this_,
-                                    const data_visible_classifier_t *visible_classifier,
-                                    const geometry_rectangle_t *classifier_bounds,
-                                    const pencil_size_t *pencil_size,
-                                    PangoLayout *font_layout,
-                                    cairo_t *cr
-                                  );
-
 #include "draw_classifier_label.inl"
 
 #endif  /* DRAW_CLASSIFIER_LABEL_H */
