@@ -251,10 +251,18 @@ static inline bool geometry_rectangle_contains ( const geometry_rectangle_t *thi
  *  \brief determines if the given rectangle has a valid (positive) size
  *
  *  \param this_ pointer to own object attributes
- *  \return false if the rectangle has a positive size.
+ *  \return false if the rectangle has a positive size (width and height).
  */
 static inline bool geometry_rectangle_is_empty ( const geometry_rectangle_t *this_ );
 
+/*!
+ *  \brief determines if the given rectangle has neither valid (positive) width nor height
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return true if the rectangle has zero width and zero height.
+ */
+static inline bool geometry_rectangle_is_point ( const geometry_rectangle_t *this_ );
+
 /*!
  *  \brief determines if the given rectangle intersects the other (not just touching)
  *
@@ -336,6 +344,15 @@ static inline void geometry_rectangle_enlarge ( geometry_rectangle_t *this_, dou
  */
 static inline void geometry_rectangle_expand_4dir ( geometry_rectangle_t *this_, double delta_width, double delta_height );
 
+/*!
+ *  \brief embraces a point so that the resulting the rectangle contains the original rectangle and the provided coordinates
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param x abscissa of the point to be embraced by the rectangle
+ *  \param y ordinate of the point to be embraced by the rectangle
+ */
+static inline void geometry_rectangle_embrace ( geometry_rectangle_t *this_, double x, double y );
+
 /*!
  *  \brief sets the left coordinate of geometry_rectangle_t
  *
