@@ -17,20 +17,24 @@
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_h_align.h"
 #include "geometry/geometry_v_align.h"
-#include "data_diagram.h"
+#include "set/data_profile_part.h"
 #include "set/data_small_set.h"
-#include "data_id.h"
 #include "set/data_visible_set.h"
+#include "data_diagram.h"
+#include "data_id.h"
 #include "u8list/universal_array_index_sorter.h"
 #include <cairo.h>
 #include <stdint.h>
 
 /*!
- *  \brief attributes of the classifier layouter
+ *  \brief attributes of the 1d-classifier layouter
+ *
+ *  \note This class is stateless. Only the layout_data, pencil_size and profile objects are stateful.
+ *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct pencil_classifier_1d_layouter_struct {
     pencil_layout_data_t *layout_data;  /* pointer to external layout data */
-
+    const data_profile_part_t *profile;  /*!< pointer to an external stereotype-image cache */
     const pencil_size_t *pencil_size;  /*!< pointer to an external pencil_size_t object, defining pen sizes, gap sizes, font sizes and colors */
     const geometry_rectangle_t *diagram_draw_area;  /*!< pointer to an external drawing rectangle containing inner contents of the diagram */
 
@@ -44,10 +48,12 @@ typedef struct pencil_classifier_1d_layouter_struct pencil_classifier_1d_layoute
  *
  *  \param this_ pointer to own object attributes
  *  \param layout_data pointer to the layout information to be used and modified
+ *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be layouted
  *  \param pencil_size pointer to the pencil_size_t object
  */
 void pencil_classifier_1d_layouter_init( pencil_classifier_1d_layouter_t *this_,
                                          pencil_layout_data_t *layout_data,
+                                         const data_profile_part_t *profile,
                                          const pencil_size_t *pencil_size
                                        );
 
