@@ -17,20 +17,25 @@
 #include "draw/draw_classifier_icon.h"
 #include "draw/draw_classifier_label.h"
 #include "draw/draw_classifier_contour.h"
+#include "draw/draw_stereotype_image.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_dimensions.h"
 #include "geometry/geometry_h_align.h"
 #include "geometry/geometry_v_align.h"
 #include "data_diagram.h"
 #include "set/data_small_set.h"
+#include "set/data_profile_part.h"
+#include "set/data_visible_set.h"
 #include "data_id.h"
 #include "data_rules.h"
-#include "set/data_visible_set.h"
 #include <cairo.h>
 #include <stdint.h>
 
 /*!
  *  \brief attributes of the classifier painter
+ *
+ *  \note This class is stateless.
+ *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct pencil_classifier_composer_struct {
     pencil_marker_t marker;  /*!< own instance of a marker */
@@ -38,6 +43,7 @@ struct pencil_classifier_composer_struct {
     draw_classifier_icon_t draw_classifier_icon;  /*!< collection of draw symbol/icon functions */
     draw_classifier_label_t draw_classifier_label;  /*!< collection of draw label functions */
     draw_classifier_contour_t draw_classifier_contour;  /*!< collection of draw contour functions */
+    draw_stereotype_image_t draw_stereotype_image;  /*!< collection of draw functions for custome stereotype images */
 };
 
 typedef struct pencil_classifier_composer_struct pencil_classifier_composer_t;
@@ -65,6 +71,7 @@ void pencil_classifier_composer_destroy( pencil_classifier_composer_t *this_ );
  *  \param mark_highlighted true if the object is to be marked as "highlighted"
  *  \param mark_selected true if the object is to be marked as "selected"
  *  \param layout_data pointer to the diagrams layout-information needed to calculate the feature compartments
+ *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be drawn
  *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param font_layout structure to layout fonts
  *  \param cr a cairo drawing context
@@ -75,6 +82,7 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
                                        data_id_t mark_highlighted,
                                        const data_small_set_t *mark_selected,
                                        const pencil_layout_data_t *layout_data,
+                                       const data_profile_part_t *profile,
                                        const pencil_size_t *pencil_size,
                                        PangoLayout *font_layout,
                                        cairo_t *cr
@@ -88,6 +96,7 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
  *  \param this_ pointer to own object attributes
  *  \param space exact new space
  *  \param shows_contained_children true if the classifier has contained children (needed for uml package because the symbol differs)
+ *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be drawn
  *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param font_layout pango layout object to determine the font metrics in the current cairo drawing context
  *  \param io_classifier_layout classifier layout of which the box coordinates shall be modified. Must not be NULL.
@@ -96,6 +105,7 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
 int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t *this_,
                                               const geometry_rectangle_t *space,
                                               bool shows_contained_children,
+                                              const data_profile_part_t *profile,
                                               const pencil_size_t *pencil_size,
                                               PangoLayout *font_layout,
                                               layout_visible_classifier_t *io_classifier_layout
@@ -109,6 +119,7 @@ int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t
  *  \param this_ pointer to own object attributes
  *  \param envelope exact new outer envelope box; should be big enough to contain the classifier
  *  \param shows_contained_children true if the classifier has contained children (needed for uml package because the symbol differs)
+ *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be drawn
  *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param font_layout pango layout object to determine the font metrics in the current cairo drawing context
  *  \param io_classifier_layout input is symbol box, output is space and label_box. Must not be NULL.
@@ -117,6 +128,7 @@ int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t
 int pencil_classifier_composer_set_envelope_box ( const pencil_classifier_composer_t *this_,
                                                   const geometry_rectangle_t *envelope,
                                                   bool shows_contained_children,
+                                                  const data_profile_part_t *profile,
                                                   const pencil_size_t *pencil_size,
                                                   PangoLayout *font_layout,
                                                   layout_visible_classifier_t *io_classifier_layout
@@ -130,6 +142,7 @@ int pencil_classifier_composer_set_envelope_box ( const pencil_classifier_compos
  *  \param this_ pointer to own object attributes
  *  \param visible_classifier the visible_classifier consisting of diagramelement and classifier to draw
  *  \param shows_contained_children true if the classifier has contained children (needed for uml package because the symbol differs)
+ *  \param with_stereotype false if no stereotype label shall be printed because an image is shown instead
  *  \param space_and_label proposed rectangle for the position, width and height of: label and icon and features and contained classifiers
  *  \param icon_dim dimensions of the label
  *  \param pencil_size set of sizes and colors for drawing lines and text
@@ -141,6 +154,7 @@ int pencil_classifier_composer_set_envelope_box ( const pencil_classifier_compos
 int pencil_classifier_composer_private_get_label_box ( const pencil_classifier_composer_t *this_,
                                                        const data_visible_classifier_t *visible_classifier,
                                                        bool shows_contained_children,
+                                                       bool with_stereotype,
                                                        const geometry_rectangle_t *space_and_label,
                                                        const geometry_dimensions_t *icon_dim,
                                                        const pencil_size_t *pencil_size,
