@@ -13,18 +13,24 @@
 #include "pencil_size.h"
 #include "layout/layout_diagram.h"
 #include "geometry/geometry_rectangle.h"
-#include "data_diagram.h"
+#include "draw/draw_diagram_label.h"
+#include "set/data_profile_part.h"
 #include "set/data_small_set.h"
-#include "data_id.h"
 #include "set/data_visible_set.h"
+#include "data_diagram.h"
+#include "data_id.h"
 #include <cairo.h>
 #include <stdint.h>
 
 /*!
  *  \brief attributes of the diagram painter
+ *
+ *  \note This class is stateless.
+ *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct pencil_diagram_painter_struct {
     pencil_marker_t marker;  /*!< own instance of a marker */
+    draw_diagram_label_t draw_diagram_label;  /*!< collection of draw label functions */
 };
 
 typedef struct pencil_diagram_painter_struct pencil_diagram_painter_t;
@@ -51,6 +57,7 @@ void pencil_diagram_painter_destroy( pencil_diagram_painter_t *this_ );
  *  \param mark_focused true if the object is to be marked as "focused"
  *  \param mark_highlighted true if the object is to be marked as "highlighted"
  *  \param mark_selected true if the object is to be marked as "selected"
+ *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be drawn
  *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param font_layout structure to layout fonts
  *  \param cr a cairo drawing context
@@ -60,26 +67,29 @@ void pencil_diagram_painter_draw ( const pencil_diagram_painter_t *this_,
                                    bool mark_focused,
                                    bool mark_highlighted,
                                    bool mark_selected,
+                                   const data_profile_part_t *profile,
                                    const pencil_size_t *pencil_size,
                                    PangoLayout *font_layout,
                                    cairo_t *cr
                                  );
 
 /*!
- *  \brief determines the inner drawing space for contained classifiers
+ *  \brief determines the label box and inner drawing space for contained classifiers
  *
  *  \param this_ pointer to own object attributes
  *  \param the_diagram pointer to the data to be drawn
- *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param diagram_bounds the destination rectangle where to draw the diagram
- *  \param out_diagram_space memory location where the result shall be stored. Must not be NULL.
+ *  \param pencil_size set of sizes and colors for drawing lines and text
+ *  \param font_layout structure to layout fonts
+ *  \param io_layout_diagram bounds, draw_area and label_box are updated. The pointer must not be NULL.
  */
-void pencil_diagram_painter_get_drawing_space ( const pencil_diagram_painter_t *this_,
-                                                const data_diagram_t *the_diagram,
-                                                const pencil_size_t *pencil_size,
-                                                const geometry_rectangle_t *diagram_bounds,
-                                                geometry_rectangle_t *out_diagram_space
-                                              );
+void pencil_diagram_painter_do_layout ( const pencil_diagram_painter_t *this_,
+                                        const data_diagram_t *the_diagram,
+                                        const geometry_rectangle_t *diagram_bounds,
+                                        const pencil_size_t *pencil_size,
+                                        PangoLayout *font_layout,
+                                        layout_diagram_t *io_layout_diagram
+                                      );
 
 #endif  /* PENCIL_DIAGRAM_PAINTER_H */
 
