@@ -24,8 +24,10 @@
 #include <stdbool.h>
 
 #ifndef NDEBUG
+#if 1
 /* make the layout visible for debugging: */
-/* define PENCIL_LAYOUT_DATA_DRAW_FOR_DEBUG */
+#define PENCIL_LAYOUT_DATA_DRAW_FOR_DEBUG
+#endif
 #endif
 
 /*!
