@@ -14,9 +14,10 @@
 #include "pencil_relationship_painter.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_non_linear_scale.h"
-#include "data_diagram.h"
+#include "set/data_profile_part.h"
 #include "set/data_small_set.h"
 #include "set/data_visible_set.h"
+#include "data_diagram.h"
 #include "data_id.h"
 #include "u8list/universal_array_index_sorter.h"
 #include "u8/u8_error.h"
@@ -25,14 +26,18 @@
 
 /*!
  *  \brief attributes of the relationship layouter
+ *
+ *  \note This class is stateless. Only the layout_data, pencil_size and profile objects are stateful.
+ *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct pencil_relationship_2d_layouter_struct {
     pencil_layout_data_t *layout_data;  /*!< pointer to an instance of layout data */
+    const data_profile_part_t *profile;  /*!< pointer to an external stereotype-image cache */
     universal_array_index_sorter_t sorted_relationships;  /*!< a sorted list of relationships, ordered by processing order, */
                                                           /*!< empty if layouting algorithm finished */
-    uint32_t sorted_rel_index;  /*!< currently processd relationship io the sorted list of relationships */
+    uint32_t sorted_rel_index;  /*!< currently processed relationship of the sorted list of relationships */
 
-    pencil_size_t *pencil_size;  /*!< pointer to an instance of a pencil_size_t object, defining pen sizes, gap sizes, */
+    const pencil_size_t *pencil_size;  /*!< pointer to an instance of a pencil_size_t object, defining pen sizes, gap sizes, */
                                  /*!< font sizes and colors */
     pencil_relationship_painter_t relationship_painter;  /*!< own instance of a painter object to ask for display dimensions */
 };
@@ -44,11 +49,13 @@ typedef struct pencil_relationship_2d_layouter_struct pencil_relationship_2d_lay
  *
  *  \param this_ pointer to own object attributes
  *  \param layout_data pointer to the layout information to be used and modified
+ *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be layouted
  *  \param pencil_size pointer to the pencil_size_t object
  */
 void pencil_relationship_2d_layouter_init( pencil_relationship_2d_layouter_t *this_,
                                            pencil_layout_data_t *layout_data,
-                                           pencil_size_t *pencil_size
+                                           const data_profile_part_t *profile,
+                                           const pencil_size_t *pencil_size
                                          );
 
 /*!
