@@ -13,20 +13,27 @@
 #include "pencil_size.h"
 #include "layout/layout_relationship.h"
 #include "draw/draw_relationship_label.h"
+#include "draw/draw_stereotype_image.h"
 #include "geometry/geometry_connector.h"
-#include "data_diagram.h"
+#include "set/data_profile_part.h"
 #include "set/data_visible_set.h"
+#include "set/data_profile_part.h"
 #include "set/data_small_set.h"
+#include "data_diagram.h"
 #include "data_id.h"
 #include <cairo.h>
 #include <stdint.h>
 
 /*!
  *  \brief attributes of the relationship painter
+ *
+ *  \note This class is stateless.
+ *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct pencil_relationship_painter_struct {
     pencil_marker_t marker;  /*!< own instance of a marker */
     draw_relationship_label_t draw_relationship_label;  /*!< collection of draw label functions */
+    draw_stereotype_image_t draw_stereotype_image;  /*!< collection of draw functions for custom stereotype images */
 };
 
 typedef struct pencil_relationship_painter_struct pencil_relationship_painter_t;
@@ -53,6 +60,7 @@ void pencil_relationship_painter_destroy( pencil_relationship_painter_t *this_ )
  *  \param mark_focused true if the object is to be marked as "focused"
  *  \param mark_highlighted true if the object is to be marked as "highlighted"
  *  \param mark_selected true if the object is to be marked as "selected"
+ *  \param profile pointer to the profile-part that provides the stereotypes of the elements to be drawn
  *  \param pencil_size set of sizes and colors for drawing lines and text
  *  \param layout structure to layout fonts
  *  \param cr a cairo drawing context
@@ -62,10 +70,11 @@ void pencil_relationship_painter_draw ( pencil_relationship_painter_t *this_,
                                         bool mark_focused,
                                         bool mark_highlighted,
                                         bool mark_selected,
+                                        const data_profile_part_t *profile,
                                         const pencil_size_t *pencil_size,
                                         PangoLayout *layout,
                                         cairo_t *cr
-                                    );
+                                      );
 
 #endif  /* PENCIL_RELATIONSHIP_PAINTER_H */
 
