@@ -19,6 +19,7 @@ static const int DRAW_CLASSIFIER_PANGO_AUTO_DETECT_LENGTH = -1;
 
 void draw_classifier_label_get_stereotype_and_name_dimensions( const draw_classifier_label_t *this_,
                                                                const data_visible_classifier_t *visible_classifier,
+                                                               bool with_stereotype,
                                                                const geometry_dimensions_t *proposed_bounds,
                                                                const pencil_size_t *pencil_size,
                                                                PangoLayout *font_layout,
@@ -46,7 +47,7 @@ void draw_classifier_label_get_stereotype_and_name_dimensions( const draw_classi
         int text1_height = 0;
         int text1_width = 0;
         {
-            if ( 0 != utf8string_get_length( data_classifier_get_stereotype_const( classifier ) ) )
+            if ( with_stereotype && data_classifier_has_stereotype( classifier ) )
             {
                 /* prepare text */
                 char stereotype_text[DATA_CLASSIFIER_MAX_STEREOTYPE_SIZE+4];
@@ -130,6 +131,7 @@ void draw_classifier_label_get_stereotype_and_name_dimensions( const draw_classi
 
 void draw_classifier_label_draw_stereotype_and_name( const draw_classifier_label_t *this_,
                                                      const data_visible_classifier_t *visible_classifier,
+                                                     bool with_stereotype,
                                                      const geometry_rectangle_t *label_box,
                                                      const pencil_size_t *pencil_size,
                                                      PangoLayout *font_layout,
@@ -158,7 +160,7 @@ void draw_classifier_label_draw_stereotype_and_name( const draw_classifier_label
     /* draw stereotype text */
     int text1_height = 0;
     {
-        if ( 0 != utf8string_get_length( data_classifier_get_stereotype_const( classifier ) ) )
+        if ( with_stereotype && data_classifier_has_stereotype( classifier ) )
         {
             /* prepare text */
             char stereotype_text[DATA_CLASSIFIER_MAX_STEREOTYPE_SIZE+4];
@@ -241,141 +243,6 @@ void draw_classifier_label_draw_stereotype_and_name( const draw_classifier_label
     U8_TRACE_END();
 }
 
-void draw_classifier_label_draw_id( const draw_classifier_label_t *this_,
-                                    const data_visible_classifier_t *visible_classifier,
-                                    const geometry_rectangle_t *classifier_bounds,
-                                    const pencil_size_t *pencil_size,
-                                    PangoLayout *font_layout,
-                                    cairo_t *cr )
-{
-    U8_TRACE_BEGIN();
-    assert( NULL != visible_classifier );
-    assert( NULL != classifier_bounds );
-    assert( NULL != pencil_size );
-    assert( NULL != font_layout );
-    assert( NULL != cr );
-
-    /* define names for input data: */
-    const double left = geometry_rectangle_get_left ( classifier_bounds );
-    const double top = geometry_rectangle_get_top ( classifier_bounds );
-    const double width = geometry_rectangle_get_width ( classifier_bounds );
-    const double height = geometry_rectangle_get_height ( classifier_bounds );
-    const double gap = pencil_size_get_standard_object_border( pencil_size );
-
-    const data_classifier_t *classifier;
-    classifier = data_visible_classifier_get_classifier_const( visible_classifier );
-    const data_classifier_type_t classifier_type = data_classifier_get_main_type( classifier );
-
-    /* prepare text */
-    const data_id_t the_id = data_classifier_get_data_id( classifier );
-
-    char id_buf[DATA_ID_MAX_UTF8STRING_SIZE+5];
-    utf8stringbuf_t id_str = UTF8STRINGBUF( id_buf );
-    utf8stringbuf_copy_str( id_str, "{id=" );
-    data_id_to_utf8stringbuf( &the_id, id_str );
-    utf8stringbuf_append_str( id_str, "}" );
-
-    /* determine text dimension */
-    int text4_width;
-    int text4_height;
-    pango_layout_set_font_description (font_layout, pencil_size_get_footnote_font_description(pencil_size) );
-    pango_layout_set_text (font_layout, utf8stringbuf_get_string( id_str ), -1);
-    pango_layout_get_pixel_size (font_layout, &text4_width, &text4_height);
-
-    /* position the text */
-    int x_gap = 0;
-    int y_gap = 0;
-    switch ( classifier_type )
-    {
-        case DATA_CLASSIFIER_TYPE_BLOCK:
-        case DATA_CLASSIFIER_TYPE_REQUIREMENT:
-        case DATA_CLASSIFIER_TYPE_SUBSYSTEM:
-        case DATA_CLASSIFIER_TYPE_DIAGRAM_REFERENCE:
-        case DATA_CLASSIFIER_TYPE_COMPONENT:
-        case DATA_CLASSIFIER_TYPE_PART:
-        case DATA_CLASSIFIER_TYPE_INTERFACE:
-        case DATA_CLASSIFIER_TYPE_PACKAGE:
-        case DATA_CLASSIFIER_TYPE_CLASS:
-        case DATA_CLASSIFIER_TYPE_OBJECT:
-        case DATA_CLASSIFIER_TYPE_ARTIFACT:
-        case DATA_CLASSIFIER_TYPE_COMMENT:
-        case DATA_CLASSIFIER_TYPE_DYN_ACCEPT_EVENT:
-        case DATA_CLASSIFIER_TYPE_STEREOTYPE:
-        {
-            /* there is a border line */
-            x_gap = 2*gap;
-            y_gap = 2*gap;
-        }
-        break;
-
-        case DATA_CLASSIFIER_TYPE_NODE:
-        {
-            /* there is a 3D border line */
-            x_gap = 4*gap;
-            y_gap = 2*gap;
-        }
-        break;
-
-        case DATA_CLASSIFIER_TYPE_CONSTRAINT_BLOCK:
-        case DATA_CLASSIFIER_TYPE_ACTIVITY:
-        case DATA_CLASSIFIER_TYPE_STATE:
-        case DATA_CLASSIFIER_TYPE_DYN_INTERRUPTABLE_REGION:
-        {
-            /* there is a border line with a round corner */
-            x_gap = 7*gap;
-            y_gap = 2*gap;
-        }
-        break;
-
-        case DATA_CLASSIFIER_TYPE_ACTOR:
-        case DATA_CLASSIFIER_TYPE_DYN_INITIAL_NODE:
-        case DATA_CLASSIFIER_TYPE_DYN_FINAL_NODE:
-        case DATA_CLASSIFIER_TYPE_DYN_FORK_NODE:
-        case DATA_CLASSIFIER_TYPE_DYN_JOIN_NODE:
-        case DATA_CLASSIFIER_TYPE_DYN_SHALLOW_HISTORY:
-        case DATA_CLASSIFIER_TYPE_DYN_DEEP_HISTORY:
-        case DATA_CLASSIFIER_TYPE_DYN_ACCEPT_TIME_EVENT:
-        {
-            /* position the text right-bottom of the icon */
-            x_gap = (width - pencil_size_get_classifier_symbol_height( pencil_size ))/2 - text4_width;
-            y_gap = 0;
-        }
-        break;
-
-        case DATA_CLASSIFIER_TYPE_USE_CASE:
-        case DATA_CLASSIFIER_TYPE_DYN_DECISION_NODE:
-        {
-            /* there is a chance that the bottom-right corner is empty */
-            x_gap = 0;
-            y_gap = 0;
-        }
-        break;
-
-        case DATA_CLASSIFIER_TYPE_DYN_SEND_SIGNAL:
-        {
-            /* the send signal has a 45 degree edge */
-            x_gap = height/2;
-            y_gap = 2*gap;
-        }
-        break;
-
-        default:
-        {
-            U8_LOG_ERROR("unknown data_classifier_type_t in pencil_classifier_composer_draw()");
-        }
-        break;
-    }
-
-    /* draw text */
-    GdkRGBA grey_color;
-    grey_color = pencil_size_get_gray_out_color( pencil_size );
-    cairo_set_source_rgba( cr, grey_color.red, grey_color.green, grey_color.blue, grey_color.alpha );
-    cairo_move_to ( cr, left + width - text4_width - x_gap, top + height - text4_height - y_gap );
-    pango_cairo_show_layout (cr, font_layout);
-
-    U8_TRACE_END();
-}
-
 
 /*
 Copyright 2016-2023 Andreas Warnke
