@@ -9,13 +9,16 @@
 
 void pencil_classifier_1d_layouter_init( pencil_classifier_1d_layouter_t *this_,
                                          pencil_layout_data_t *layout_data,
+                                         const data_profile_part_t *profile,
                                          const pencil_size_t *pencil_size )
 {
     U8_TRACE_BEGIN();
     assert( NULL != layout_data );
+    assert( NULL != profile );
     assert( NULL != pencil_size );
 
     (*this_).layout_data = layout_data;
+    (*this_).profile = profile;
     (*this_).pencil_size = pencil_size;
     pencil_classifier_composer_init( &((*this_).classifier_composer) );
 
@@ -90,6 +93,7 @@ void pencil_classifier_1d_layouter_layout_for_list( pencil_classifier_1d_layoute
             pencil_classifier_composer_set_envelope_box( &((*this_).classifier_composer),
                                                          &envelope_box,
                                                          has_contained_children,
+                                                         (*this_).profile,
                                                          (*this_).pencil_size,
                                                          font_layout,
                                                          visible_classifier1
@@ -202,6 +206,7 @@ void pencil_classifier_1d_layouter_layout_for_sequence( pencil_classifier_1d_lay
             pencil_classifier_composer_set_envelope_box( &((*this_).classifier_composer),
                                                          &envelope_box,
                                                          has_contained_children,
+                                                         (*this_).profile,
                                                          (*this_).pencil_size,
                                                          font_layout,
                                                          visible_classifier1
@@ -324,6 +329,7 @@ void pencil_classifier_1d_layouter_layout_for_timing( pencil_classifier_1d_layou
             pencil_classifier_composer_set_envelope_box( &((*this_).classifier_composer),
                                                          &envelope_box,
                                                          has_contained_children,
+                                                         (*this_).profile,
                                                          (*this_).pencil_size,
                                                          font_layout,
                                                          visible_classifier1
