@@ -9,6 +9,7 @@
 
 void pencil_classifier_2d_layouter_init( pencil_classifier_2d_layouter_t *this_,
                                          pencil_layout_data_t *layout_data,
+                                         const data_profile_part_t *profile,
                                          const pencil_size_t *pencil_size,
                                          geometry_dimensions_t *default_classifier_size,
                                          geometry_non_linear_scale_t *x_scale,
@@ -17,6 +18,7 @@ void pencil_classifier_2d_layouter_init( pencil_classifier_2d_layouter_t *this_,
 {
     U8_TRACE_BEGIN();
     assert( NULL != layout_data );
+    assert( NULL != profile );
     assert( NULL != pencil_size );
     assert( NULL != default_classifier_size );
     assert( NULL != x_scale );
@@ -24,6 +26,7 @@ void pencil_classifier_2d_layouter_init( pencil_classifier_2d_layouter_t *this_,
     assert( NULL != feature_layouter );
 
     (*this_).layout_data = layout_data;
+    (*this_).profile = profile;
     (*this_).pencil_size = pencil_size;
     (*this_).default_classifier_size = default_classifier_size;
     (*this_).x_scale = x_scale;
@@ -80,6 +83,7 @@ void pencil_classifier_2d_layouter_estimate_bounds( pencil_classifier_2d_layoute
                 pencil_classifier_composer_set_envelope_box( &((*this_).classifier_composer),
                                                              &envelope,
                                                              shows_contained_children,
+                                                             (*this_).profile,
                                                              (*this_).pencil_size,
                                                              font_layout,
                                                              classifier_layout
@@ -117,6 +121,7 @@ void pencil_classifier_2d_layouter_estimate_bounds( pencil_classifier_2d_layoute
                     pencil_classifier_composer_expand_space( &((*this_).classifier_composer),
                                                              &new_space,
                                                              shows_contained_children,
+                                                             (*this_).profile,
                                                              (*this_).pencil_size,
                                                              font_layout,
                                                              classifier_layout
@@ -836,6 +841,7 @@ int pencil_classifier_2d_layouter_private_try_embrace_child( pencil_classifier_2
             pencil_classifier_composer_expand_space( &((*this_).classifier_composer),
                                                      &probe_space,
                                                      true,  /* = shows_contained_children */
+                                                     (*this_).profile,
                                                      (*this_).pencil_size,
                                                      font_layout,
                                                      &probe_parent_layout
@@ -990,6 +996,7 @@ void pencil_classifier_2d_layouter_move_and_embrace_children( pencil_classifier_
             pencil_classifier_composer_expand_space( &((*this_).classifier_composer),
                                                      &children_envelope,
                                                      true,  /* = shows_contained_children */
+                                                     (*this_).profile,
                                                      (*this_).pencil_size,
                                                      font_layout,
                                                      &probe_parent_layout
@@ -1014,6 +1021,7 @@ void pencil_classifier_2d_layouter_move_and_embrace_children( pencil_classifier_
                 pencil_classifier_composer_set_envelope_box( &((*this_).classifier_composer),
                                                              &new_envelope,
                                                              true,  /* = shows_contained_children */
+                                                             (*this_).profile,
                                                              (*this_).pencil_size,
                                                              font_layout,
                                                              the_classifier
