@@ -18,6 +18,7 @@ void pencil_classifier_composer_init( pencil_classifier_composer_t *this_ )
     draw_classifier_icon_init( &((*this_).draw_classifier_icon) );
     draw_classifier_label_init( &((*this_).draw_classifier_label) );
     draw_classifier_contour_init( &((*this_).draw_classifier_contour) );
+    draw_stereotype_image_init( &((*this_).draw_stereotype_image) );
 
     U8_TRACE_END();
 }
@@ -29,6 +30,7 @@ void pencil_classifier_composer_destroy( pencil_classifier_composer_t *this_ )
     draw_classifier_icon_destroy( &((*this_).draw_classifier_icon) );
     draw_classifier_label_destroy( &((*this_).draw_classifier_label) );
     draw_classifier_contour_destroy( &((*this_).draw_classifier_contour) );
+    draw_stereotype_image_destroy( &((*this_).draw_stereotype_image) );
     data_rules_destroy ( &((*this_).data_rules) );
     pencil_marker_destroy( &((*this_).marker) );
 
@@ -41,14 +43,17 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
                                        data_id_t mark_highlighted,
                                        const data_small_set_t *mark_selected,
                                        const pencil_layout_data_t *layout_data,
+                                       const data_profile_part_t *profile,
                                        const pencil_size_t *pencil_size,
                                        PangoLayout *font_layout,
                                        cairo_t *cr )
 {
     U8_TRACE_BEGIN();
-    assert( NULL != pencil_size );
     assert( NULL != layouted_classifier );
+    assert( NULL != mark_selected );
     assert( NULL != layout_data );
+    assert( NULL != profile );
+    assert( NULL != pencil_size );
     assert( NULL != font_layout );
     assert( NULL != cr );
 
@@ -56,62 +61,104 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
         = layout_visible_classifier_get_data_const( layouted_classifier );
     const geometry_rectangle_t *const classifier_symbol_box
         = layout_visible_classifier_get_symbol_box_const( layouted_classifier );
+    const geometry_rectangle_t *const classifier_label_box
+        = layout_visible_classifier_get_label_box_const( layouted_classifier );
     const data_classifier_t *const classifier
         = data_visible_classifier_get_classifier_const( visible_classifier );
     const data_diagramelement_t *const diagramelement
         = data_visible_classifier_get_diagramelement_const( visible_classifier );
     const data_classifier_type_t classifier_type = data_classifier_get_main_type( classifier );
+    const char *const classifier_stereotype = data_classifier_get_stereotype_const( classifier );
+    const bool has_stereotype_image
+        = draw_stereotype_image_exists( &((*this_).draw_stereotype_image), classifier_stereotype, profile );
+    const data_diagramelement_flag_t display_flags
+        = data_diagramelement_get_display_flags( diagramelement );
 
     const double gap = pencil_size_get_standard_object_border( pencil_size );
+    const double std_line_width = pencil_size_get_standard_line_width( pencil_size );
+    /* set the right drawing color */
+    GdkRGBA foreground_color;
+    {
+        if ( data_id_equals_id( &mark_highlighted, DATA_TABLE_DIAGRAMELEMENT, data_diagramelement_get_row_id( diagramelement ) ) )
+        {
+            foreground_color = pencil_size_get_highlight_color( pencil_size );
+        }
+        else if ( 0 != ( display_flags & DATA_DIAGRAMELEMENT_FLAG_GRAY_OUT ))
+        {
+            foreground_color = pencil_size_get_gray_out_color( pencil_size );
+        }
+        else
+        {
+            foreground_color = pencil_size_get_standard_color( pencil_size );
+        }
+    }
 
-    /* draw id */
-    draw_classifier_label_draw_id( &((*this_).draw_classifier_label),
-                                   visible_classifier,
-                                   classifier_symbol_box,
-                                   pencil_size,
-                                   font_layout,
-                                   cr
-                                 );
+    U8_TRACE_INFO_INT("drawing classifier id", data_classifier_get_row_id( classifier ) );
+
+    /* draw the stereotype image */
+    bool icon_override = false;  /* in case of a stereotype image, the icon shall not be drawn. */
+    if ( has_stereotype_image )
+    {
+        /* check if the image is a small icon within a contour or if it is the full symbol */
+        const bool has_contour = geometry_rectangle_is_containing( classifier_symbol_box, classifier_label_box );
+
+        /* determine border sizes of the classifier-shape */
+        const geometry_rectangle_t space_and_label
+            = has_contour
+            ? draw_classifier_contour_calc_inner_area( &((*this_).draw_classifier_contour),
+                                                       classifier_type,
+                                                       classifier_symbol_box,
+                                                       pencil_size
+                                                     )
+            : (*classifier_symbol_box);
+
+        /* draw icon */
+        cairo_set_line_width( cr, std_line_width );
+        /* cairo_set_source_rgba( cr, foreground_color.red, foreground_color.green, foreground_color.blue, foreground_color.alpha ); */
+        const geometry_rectangle_t stereotype_box
+            = has_contour
+            ? draw_stereotype_image_get_bounds( &((*this_).draw_stereotype_image),
+                                                geometry_rectangle_get_right( &space_and_label ),  /* x */
+                                                geometry_rectangle_get_top( &space_and_label ),  /* y */
+                                                GEOMETRY_H_ALIGN_RIGHT,
+                                                GEOMETRY_V_ALIGN_TOP,
+                                                pencil_size
+                                              )
+            : (*classifier_symbol_box);
+        u8_error_info_t err_info;
+        const u8_error_t stereotype_err
+            = draw_stereotype_image_draw( &((*this_).draw_stereotype_image),
+                                          data_classifier_get_stereotype_const( classifier ),
+                                          profile,
+                                          &foreground_color,
+                                          &err_info,
+                                          &stereotype_box,
+                                          cr
+                                        );
+        if ( u8_error_info_is_error( &err_info ) )
+        {
+            U8_LOG_WARNING_INT( "stereotype image: unxpected token in svg path in line", u8_error_info_get_line( &err_info ) );
+        }
+        icon_override = ( stereotype_err == U8_ERROR_NONE );
+    }
 
     /* draw the classifier */
     {
-        const data_diagramelement_flag_t display_flags
-            = data_diagramelement_get_display_flags( diagramelement );
-
-        U8_TRACE_INFO_INT("drawing classifier id", data_classifier_get_row_id( classifier ) );
-
-        const double std_line_width = pencil_size_get_standard_line_width( pencil_size );
+        /* set line width */
         cairo_set_line_width( cr, std_line_width );
-
         /* set color */
-        GdkRGBA foreground_color;
-        {
-            if ( data_id_equals_id( &mark_highlighted, DATA_TABLE_DIAGRAMELEMENT, data_diagramelement_get_row_id( diagramelement ) ) )
-            {
-                foreground_color = pencil_size_get_highlight_color( pencil_size );
-            }
-            else if ( 0 != ( display_flags & DATA_DIAGRAMELEMENT_FLAG_GRAY_OUT ))
-            {
-                foreground_color = pencil_size_get_gray_out_color( pencil_size );
-            }
-            else
-            {
-                foreground_color = pencil_size_get_standard_color( pencil_size );
-            }
-            cairo_set_source_rgba( cr, foreground_color.red, foreground_color.green, foreground_color.blue, foreground_color.alpha );
-        }
+        cairo_set_source_rgba( cr, foreground_color.red, foreground_color.green, foreground_color.blue, foreground_color.alpha );
 
         /* highlight */
         if ( 0 != ( display_flags & DATA_DIAGRAMELEMENT_FLAG_EMPHASIS ))
         {
             const GdkRGBA emph_color = pencil_size_get_emphasized_bgcolor( pencil_size );
             cairo_set_source_rgba( cr, emph_color.red, emph_color.green, emph_color.blue, emph_color.alpha );
-            const geometry_rectangle_t *const box = layout_visible_classifier_get_label_box_const( layouted_classifier );
             cairo_rectangle ( cr,
-                              geometry_rectangle_get_left(box),
-                              geometry_rectangle_get_top(box),
-                              geometry_rectangle_get_width(box),
-                              geometry_rectangle_get_height(box)
+                              geometry_rectangle_get_left( classifier_label_box ),
+                              geometry_rectangle_get_top( classifier_label_box ),
+                              geometry_rectangle_get_width( classifier_label_box ),
+                              geometry_rectangle_get_height( classifier_label_box )
                             );
             cairo_fill (cr);
             cairo_set_source_rgba( cr, foreground_color.red, foreground_color.green, foreground_color.blue, foreground_color.alpha );
@@ -120,7 +167,8 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
         /* draw label */
         draw_classifier_label_draw_stereotype_and_name( &((*this_).draw_classifier_label),
                                                         visible_classifier,
-                                                        layout_visible_classifier_get_label_box_const( layouted_classifier ),
+                                                        ( ! has_stereotype_image ),
+                                                        classifier_label_box,
                                                         pencil_size,
                                                         font_layout,
                                                         cr
@@ -176,7 +224,10 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
                                                                  GEOMETRY_V_ALIGN_TOP,
                                                                  component_icon_height
                                                                );
-                draw_classifier_icon_draw_component ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                if ( ! icon_override )
+                {
+                    draw_classifier_icon_draw_component ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                }
             }
             break;
 
@@ -194,7 +245,10 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
                                                                 GEOMETRY_V_ALIGN_TOP,
                                                                 artifact_icon_height
                                                               );
-                draw_classifier_icon_draw_artifact ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                if ( ! icon_override )
+                {
+                    draw_classifier_icon_draw_artifact ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                }
             }
             break;
 
@@ -238,17 +292,20 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
 
             case DATA_CLASSIFIER_TYPE_ACTOR:
             {
-                const double actor_height = icon_height;
-                const double half_width = 0.5 * icon_width;
-                const geometry_rectangle_t icon_bounds
-                    = draw_classifier_icon_get_actor_bounds( &((*this_).draw_classifier_icon),
-                                                             icon_left + half_width,
-                                                             icon_top,
-                                                             GEOMETRY_H_ALIGN_CENTER,
-                                                             GEOMETRY_V_ALIGN_TOP,
-                                                             actor_height
-                                                           );
-                draw_classifier_icon_draw_actor ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                if ( ! icon_override )
+                {
+                    const double actor_height = icon_height;
+                    const double half_width = 0.5 * icon_width;
+                    const geometry_rectangle_t icon_bounds
+                        = draw_classifier_icon_get_actor_bounds( &((*this_).draw_classifier_icon),
+                                                                 icon_left + half_width,
+                                                                 icon_top,
+                                                                 GEOMETRY_H_ALIGN_CENTER,
+                                                                 GEOMETRY_V_ALIGN_TOP,
+                                                                 actor_height
+                                                               );
+                    draw_classifier_icon_draw_actor ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                }
             }
             break;
 
@@ -257,30 +314,33 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
             case DATA_CLASSIFIER_TYPE_DYN_SHALLOW_HISTORY:
             case DATA_CLASSIFIER_TYPE_DYN_DEEP_HISTORY:
             {
-                const double circle_diameter = icon_height;
-                const double half_width = 0.5 * icon_width;
-                const geometry_rectangle_t icon_bounds
-                    = draw_classifier_icon_get_circle_bounds( &((*this_).draw_classifier_icon),
-                                                              icon_left + half_width,
-                                                              icon_top,
-                                                              GEOMETRY_H_ALIGN_CENTER,
-                                                              GEOMETRY_V_ALIGN_TOP,
-                                                              circle_diameter
-                                                            );
-                const bool stroke = ( classifier_type != DATA_CLASSIFIER_TYPE_DYN_INITIAL_NODE );
-                const bool fill = ( ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_INITIAL_NODE )
-                                  || ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_FINAL_NODE ) );
-                const bool shallow_history = ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_SHALLOW_HISTORY );
-                const bool deep_history = ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_DEEP_HISTORY );
-                draw_classifier_icon_draw_circle( &((*this_).draw_classifier_icon),
-                                                  icon_bounds,
-                                                  pencil_size,
-                                                  stroke,
-                                                  fill,
-                                                  shallow_history,
-                                                  deep_history,
-                                                  cr
-                                                );
+                if ( ! icon_override )
+                {
+                    const double circle_diameter = icon_height;
+                    const double half_width = 0.5 * icon_width;
+                    const geometry_rectangle_t icon_bounds
+                        = draw_classifier_icon_get_circle_bounds( &((*this_).draw_classifier_icon),
+                                                                  icon_left + half_width,
+                                                                  icon_top,
+                                                                  GEOMETRY_H_ALIGN_CENTER,
+                                                                  GEOMETRY_V_ALIGN_TOP,
+                                                                  circle_diameter
+                                                                );
+                    const bool stroke = ( classifier_type != DATA_CLASSIFIER_TYPE_DYN_INITIAL_NODE );
+                    const bool fill = ( ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_INITIAL_NODE )
+                                    || ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_FINAL_NODE ) );
+                    const bool shallow_history = ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_SHALLOW_HISTORY );
+                    const bool deep_history = ( classifier_type == DATA_CLASSIFIER_TYPE_DYN_DEEP_HISTORY );
+                    draw_classifier_icon_draw_circle( &((*this_).draw_classifier_icon),
+                                                      icon_bounds,
+                                                      pencil_size,
+                                                      stroke,
+                                                      fill,
+                                                      shallow_history,
+                                                      deep_history,
+                                                      cr
+                                                    );
+                }
             }
             break;
 
@@ -298,35 +358,41 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
 
             case DATA_CLASSIFIER_TYPE_DYN_ACCEPT_TIME_EVENT:
             {
-                const double time_icon_height = icon_height;
-                const double half_width = 0.5 * icon_width;
-                const geometry_rectangle_t icon_bounds
-                    = draw_classifier_icon_get_time_bounds( &((*this_).draw_classifier_icon),
-                                                            icon_left + half_width,
-                                                            icon_top,
-                                                            GEOMETRY_H_ALIGN_CENTER,
-                                                            GEOMETRY_V_ALIGN_TOP,
-                                                            time_icon_height
-                                                          );
-                draw_classifier_icon_draw_time ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                if ( ! icon_override )
+                {
+                    const double time_icon_height = icon_height;
+                    const double half_width = 0.5 * icon_width;
+                    const geometry_rectangle_t icon_bounds
+                        = draw_classifier_icon_get_time_bounds( &((*this_).draw_classifier_icon),
+                                                                icon_left + half_width,
+                                                                icon_top,
+                                                                GEOMETRY_H_ALIGN_CENTER,
+                                                                GEOMETRY_V_ALIGN_TOP,
+                                                                time_icon_height
+                                                              );
+                    draw_classifier_icon_draw_time ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                }
             }
             break;
 
             case DATA_CLASSIFIER_TYPE_DYN_FORK_NODE:
             case DATA_CLASSIFIER_TYPE_DYN_JOIN_NODE:
             {
-                const double box_icon_height = icon_height;
-                const double half_width = 0.5 * icon_width;
-                const geometry_rectangle_t icon_bounds
-                    = draw_classifier_icon_get_sync_bounds( &((*this_).draw_classifier_icon),
-                                                            icon_left + half_width,
-                                                            icon_top,
-                                                            GEOMETRY_H_ALIGN_CENTER,
-                                                            GEOMETRY_V_ALIGN_TOP,
-                                                            box_icon_height,
-                                                            pencil_size
-                                                          );
-                draw_classifier_icon_draw_sync ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                if ( ! icon_override )
+                {
+                    const double box_icon_height = icon_height;
+                    const double half_width = 0.5 * icon_width;
+                    const geometry_rectangle_t icon_bounds
+                        = draw_classifier_icon_get_sync_bounds( &((*this_).draw_classifier_icon),
+                                                                icon_left + half_width,
+                                                                icon_top,
+                                                                GEOMETRY_H_ALIGN_CENTER,
+                                                                GEOMETRY_V_ALIGN_TOP,
+                                                                box_icon_height,
+                                                                pencil_size
+                                                              );
+                    draw_classifier_icon_draw_sync ( &((*this_).draw_classifier_icon), icon_bounds, cr );
+                }
             }
             break;
 
@@ -350,8 +416,6 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
 
             case DATA_CLASSIFIER_TYPE_PACKAGE:
             {
-                const geometry_rectangle_t *const classifier_label_box
-                    = layout_visible_classifier_get_label_box_const( layouted_classifier );
                 draw_classifier_contour_draw_package( &((*this_).draw_classifier_contour),
                                                       classifier_symbol_box,
                                                       classifier_label_box,
@@ -367,6 +431,15 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
             }
             break;
 
+            case DATA_CLASSIFIER_TYPE_IMAGE:
+            {
+                if ( ! icon_override )
+                {
+                    draw_classifier_contour_draw_rect ( &((*this_).draw_classifier_contour), classifier_symbol_box, pencil_size, cr );
+                }
+            }
+            break;
+
             default:
             {
                 U8_LOG_ERROR("unknown data_classifier_type_t in pencil_classifier_composer_draw()");
@@ -423,6 +496,7 @@ void pencil_classifier_composer_draw ( const pencil_classifier_composer_t *this_
 int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t *this_,
                                               const geometry_rectangle_t *space,
                                               bool shows_contained_children,
+                                              const data_profile_part_t *profile,
                                               const pencil_size_t *pencil_size,
                                               PangoLayout *font_layout,
                                               layout_visible_classifier_t *io_classifier_layout )
@@ -440,13 +514,20 @@ int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t
         = data_visible_classifier_get_classifier_const( visible_classifier );
     const data_classifier_type_t classifier_type
         = data_classifier_get_main_type( classifier );
+    const char *const classifier_stereotype = data_classifier_get_stereotype_const( classifier );
+    const bool has_stereotype_image
+        = draw_stereotype_image_exists( &((*this_).draw_stereotype_image), classifier_stereotype, profile );
 
     U8_TRACE_INFO_INT("expanding bounds of classifier id:", data_classifier_get_row_id( classifier ) );
     U8_TRACE_INFO_INT_INT("expanding bounds of classifier type, children:", classifier_type, shows_contained_children?1:0 );
 
     /* determine icon space */
     const geometry_dimensions_t icon_dim
-        = draw_classifier_icon_get_icon_dimensions( &((*this_).draw_classifier_icon),
+        = has_stereotype_image
+        ? draw_stereotype_image_get_dimensions( &((*this_).draw_stereotype_image),
+                                                pencil_size
+                                              )
+        : draw_classifier_icon_get_icon_dimensions( &((*this_).draw_classifier_icon),
                                                     classifier_type,
                                                     pencil_size
                                                   );
@@ -461,6 +542,7 @@ int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t
         = pencil_classifier_composer_private_get_label_box( this_,
                                                             visible_classifier,
                                                             shows_contained_children,
+                                                            ( ! has_stereotype_image ),
                                                             space_and_label_fake,
                                                             &icon_dim,
                                                             pencil_size,
@@ -479,31 +561,10 @@ int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t
     /* sizes of geometric objects are determined, */
     /* now position the geometric objects */
     {
-        const bool is_fix_sized_symbol
-            = draw_classifier_icon_is_fix_sized_symbol( &((*this_).draw_classifier_icon), classifier_type );
+        const bool has_contour
+            = draw_classifier_contour_has_contour( &((*this_).draw_classifier_contour), classifier_type );
 
-        if ( is_fix_sized_symbol )
-        {
-            U8_TRACE_INFO("calculating symbol box for fixed-sized icon..." );
-
-            const double symbol_height = pencil_size_get_classifier_symbol_height( pencil_size );
-            const double symbol_width = symbol_height;
-
-            /* calculate symbol bounds */
-            const geometry_h_align_t H_CENTER = GEOMETRY_H_ALIGN_CENTER;
-            const double symbol_left
-                = geometry_h_align_get_left( &H_CENTER,
-                                             symbol_width,
-                                             geometry_rectangle_get_left( space ),
-                                             geometry_rectangle_get_width( space )
-                                           );
-            const double symbol_top = geometry_rectangle_get_top( &label_compartment ) - symbol_height;
-            geometry_rectangle_t classifier_symbol_box;
-            geometry_rectangle_init( &classifier_symbol_box, symbol_left, symbol_top, symbol_width, symbol_height );
-            layout_visible_classifier_set_symbol_box( io_classifier_layout, &classifier_symbol_box );
-            geometry_rectangle_destroy( &classifier_symbol_box );
-        }
-        else
+        if ( has_contour )
         {
             U8_TRACE_INFO("calculating symbol box as envelope around label and space..." );
 
@@ -534,6 +595,27 @@ int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t
             layout_visible_classifier_set_symbol_box( io_classifier_layout, &envelope );
             geometry_rectangle_destroy( &inner_area );
         }
+        else
+        {
+            U8_TRACE_INFO("calculating symbol box for fixed-sized icon..." );
+
+            const double symbol_height = pencil_size_get_classifier_symbol_height( pencil_size );
+            const double symbol_width = symbol_height;
+
+            /* calculate symbol bounds */
+            const geometry_h_align_t H_CENTER = GEOMETRY_H_ALIGN_CENTER;
+            const double symbol_left
+                = geometry_h_align_get_left( &H_CENTER,
+                                             symbol_width,
+                                             geometry_rectangle_get_left( space ),
+                                             geometry_rectangle_get_width( space )
+                                           );
+            const double symbol_top = geometry_rectangle_get_top( &label_compartment ) - symbol_height;
+            geometry_rectangle_t classifier_symbol_box;
+            geometry_rectangle_init( &classifier_symbol_box, symbol_left, symbol_top, symbol_width, symbol_height );
+            layout_visible_classifier_set_symbol_box( io_classifier_layout, &classifier_symbol_box );
+            geometry_rectangle_destroy( &classifier_symbol_box );
+        }
 
         /* calculate label_box */
         layout_visible_classifier_set_label_box( io_classifier_layout, &label_rect );
@@ -572,6 +654,7 @@ int pencil_classifier_composer_expand_space ( const pencil_classifier_composer_t
 int pencil_classifier_composer_set_envelope_box( const pencil_classifier_composer_t *this_,
                                                  const geometry_rectangle_t *envelope,
                                                  bool shows_contained_children,
+                                                 const data_profile_part_t *profile,
                                                  const pencil_size_t *pencil_size,
                                                  PangoLayout *font_layout,
                                                  layout_visible_classifier_t *io_classifier_layout )
@@ -589,13 +672,20 @@ int pencil_classifier_composer_set_envelope_box( const pencil_classifier_compose
         = data_visible_classifier_get_classifier_const( visible_classifier );
     const data_classifier_type_t classifier_type
         = data_classifier_get_main_type( classifier );
+    const char *const classifier_stereotype = data_classifier_get_stereotype_const( classifier );
+    const bool has_stereotype_image
+        = draw_stereotype_image_exists( &((*this_).draw_stereotype_image), classifier_stereotype, profile );
 
     U8_TRACE_INFO_INT("calculating bounds of classifier id, type:", data_classifier_get_row_id( classifier ) );
     U8_TRACE_INFO_INT_INT("calculating bounds of classifier type, children:", classifier_type, shows_contained_children?1:0 );
 
     /* determine icon space */
     const geometry_dimensions_t icon_dim
-        = draw_classifier_icon_get_icon_dimensions( &((*this_).draw_classifier_icon),
+        = has_stereotype_image
+        ? draw_stereotype_image_get_dimensions( &((*this_).draw_stereotype_image),
+                                                pencil_size
+                                              )
+        : draw_classifier_icon_get_icon_dimensions( &((*this_).draw_classifier_icon),
                                                     classifier_type,
                                                     pencil_size
                                                   );
@@ -617,6 +707,7 @@ int pencil_classifier_composer_set_envelope_box( const pencil_classifier_compose
         = pencil_classifier_composer_private_get_label_box( this_,
                                                             visible_classifier,
                                                             shows_contained_children,
+                                                            ( ! has_stereotype_image ),
                                                             &space_and_label,
                                                             &icon_dim,
                                                             pencil_size,
@@ -628,14 +719,25 @@ int pencil_classifier_composer_set_envelope_box( const pencil_classifier_compose
     /* if label fits into space_and_label */
     if ( 0 == area_too_small )
     {
-        const bool is_fix_sized_symbol
-            = draw_classifier_icon_is_fix_sized_symbol( &((*this_).draw_classifier_icon), classifier_type );
+        const bool has_contour
+            = draw_classifier_contour_has_contour( &((*this_).draw_classifier_contour), classifier_type );
 
         /* get the symbol and label boxes and inner space rectangles to modify */
         geometry_rectangle_t classifier_space;
         geometry_rectangle_copy( &classifier_space, &space_and_label );
 
-        if ( is_fix_sized_symbol )
+        if ( has_contour )
+        {
+            U8_TRACE_INFO("calculating symbol box as envelope around label and space..." );
+
+            /* calculate symbol bounds */
+            layout_visible_classifier_set_symbol_box( io_classifier_layout, envelope );
+
+            /* calculate space */
+            geometry_rectangle_shift( &classifier_space, 0.0, geometry_rectangle_get_height( &label_compartment ) );
+            geometry_rectangle_enlarge( &classifier_space, 0.0, -geometry_rectangle_get_height( &label_compartment ) );
+        }
+        else
         {
             U8_TRACE_INFO("calculating symbol box for fixed-sized icon..." );
 
@@ -661,17 +763,6 @@ int pencil_classifier_composer_set_envelope_box( const pencil_classifier_compose
             geometry_rectangle_shift( &classifier_space, 0.0, label_and_symbol_height );
             geometry_rectangle_enlarge( &classifier_space, 0.0, -label_and_symbol_height );
         }
-        else
-        {
-            U8_TRACE_INFO("calculating symbol box as envelope around label and space..." );
-
-            /* calculate symbol bounds */
-            layout_visible_classifier_set_symbol_box( io_classifier_layout, envelope );
-
-            /* calculate space */
-            geometry_rectangle_shift( &classifier_space, 0.0, geometry_rectangle_get_height( &label_compartment ) );
-            geometry_rectangle_enlarge( &classifier_space, 0.0, -geometry_rectangle_get_height( &label_compartment ) );
-        }
         layout_visible_classifier_set_space( io_classifier_layout, &classifier_space );
 
 
@@ -702,6 +793,7 @@ int pencil_classifier_composer_set_envelope_box( const pencil_classifier_compose
         pencil_classifier_composer_expand_space( this_,
                                                  &space_guess,
                                                  shows_contained_children,
+                                                 profile,
                                                  pencil_size,
                                                  font_layout,
                                                  io_classifier_layout
@@ -728,6 +820,7 @@ static inline double PENCIL_MAX_OF_2 ( double a, double b ) { return (a<b) ? b :
 int pencil_classifier_composer_private_get_label_box ( const pencil_classifier_composer_t *this_,
                                                        const data_visible_classifier_t *visible_classifier,
                                                        bool shows_contained_children,
+                                                       bool with_stereotype,
                                                        const geometry_rectangle_t *space_and_label,
                                                        const geometry_dimensions_t *icon_dim,
                                                        const pencil_size_t *pencil_size,
@@ -758,19 +851,20 @@ int pencil_classifier_composer_private_get_label_box ( const pencil_classifier_c
     /* determine stereotype and name dimensions */
     double text_width;
     double text_height;
-    const bool is_fix_sized_symbol
-        = draw_classifier_icon_is_fix_sized_symbol( &((*this_).draw_classifier_icon), classifier_type );
+    const bool has_contour
+        = draw_classifier_contour_has_contour( &((*this_).draw_classifier_contour), classifier_type );
     const double icon_gap
-        = is_fix_sized_symbol ? 0.0 : ( geometry_dimensions_get_width( icon_dim ) < 0.000001 ) ? 0.0 : gap;
+        = ( ! has_contour ) ? 0.0 : ( geometry_dimensions_get_width( icon_dim ) < 0.000001 ) ? 0.0 : gap;
     {
         const double proposed_label_width
-            = is_fix_sized_symbol
-            ? geometry_rectangle_get_width( space_and_label )
-            : geometry_rectangle_get_width( space_and_label ) - geometry_dimensions_get_width( icon_dim ) - icon_gap;
+            = has_contour
+            ? geometry_rectangle_get_width( space_and_label ) - geometry_dimensions_get_width( icon_dim ) - icon_gap
+            : geometry_rectangle_get_width( space_and_label );
         geometry_dimensions_t proposed_label_dim;
         geometry_dimensions_init( &proposed_label_dim, proposed_label_width, geometry_rectangle_get_height( space_and_label ) );
         draw_classifier_label_get_stereotype_and_name_dimensions( &((*this_).draw_classifier_label),
                                                                   visible_classifier,
+                                                                  with_stereotype,
                                                                   &proposed_label_dim,
                                                                   pencil_size,
                                                                   font_layout,
@@ -792,7 +886,7 @@ int pencil_classifier_composer_private_get_label_box ( const pencil_classifier_c
         }
     }
 
-    if ( ! is_fix_sized_symbol )
+    if ( has_contour )
     {
         double top_border = geometry_rectangle_get_top( space_and_label );
 
