@@ -7,10 +7,13 @@
 #include <stdlib.h>
 #include <math.h>
 
-void pencil_layouter_init( pencil_layouter_t *this_, const data_visible_set_t *input_data )
+void pencil_layouter_init( pencil_layouter_t *this_,
+                           const data_visible_set_t *input_data,
+                           const data_profile_part_t *profile )
 {
     U8_TRACE_BEGIN();
     assert( NULL != input_data );
+    assert( NULL != profile );
 
     pencil_size_init_empty( &((*this_).pencil_size) );
     geometry_non_linear_scale_init( &((*this_).x_scale), 0.0, 1.0 );
@@ -18,7 +21,9 @@ void pencil_layouter_init( pencil_layouter_t *this_, const data_visible_set_t *i
     geometry_dimensions_init_empty( &((*this_).default_classifier_size) );
     data_rules_init( &((*this_).rules) );
 
+    /* initialize the layout data objects */
     pencil_layout_data_init( &((*this_).layout_data), input_data );
+    (*this_).profile = profile;
 
     pencil_diagram_painter_init( &((*this_).diagram_painter) );
 
@@ -32,6 +37,7 @@ void pencil_layouter_init( pencil_layouter_t *this_, const data_visible_set_t *i
                                    );
     pencil_classifier_2d_layouter_init( &((*this_).pencil_classifier_2d_layouter),
                                         &((*this_).layout_data),
+                                        profile,
                                         &((*this_).pencil_size),
                                         &((*this_).default_classifier_size),
                                         &((*this_).x_scale),
@@ -40,30 +46,38 @@ void pencil_layouter_init( pencil_layouter_t *this_, const data_visible_set_t *i
                                       );
     pencil_classifier_1d_layouter_init( &((*this_).pencil_classifier_1d_layouter),
                                         &((*this_).layout_data),
+                                        profile,
                                         &((*this_).pencil_size)
                                       );
     pencil_relationship_2d_layouter_init( &((*this_).pencil_relationship_2d_layouter),
-                                       &((*this_).layout_data),
-                                       &((*this_).pencil_size)
-                                     );
+                                          &((*this_).layout_data),
+                                          profile,
+                                          &((*this_).pencil_size)
+                                        );
     pencil_relationship_1d_layouter_init( &((*this_).pencil_relationship_1d_layouter),
                                           &((*this_).layout_data),
+                                          profile,
                                           &((*this_).pencil_size)
                                         );
     pencil_rel_label_layouter_init( &((*this_).relationship_label_layouter),
                                     &((*this_).layout_data),
+                                    profile,
                                     &((*this_).pencil_size)
                                   );
     U8_TRACE_END();
 }
 
-void pencil_layouter_reinit( pencil_layouter_t *this_, const data_visible_set_t *input_data )
+void pencil_layouter_reinit( pencil_layouter_t *this_,
+                             const data_visible_set_t *input_data,
+                             const data_profile_part_t *profile )
 {
     U8_TRACE_BEGIN();
     assert( NULL != input_data );
+    assert( NULL != profile );
 
     /* re-initialize the layout data objects */
     pencil_layout_data_reinit( &((*this_).layout_data), input_data );
+    (*this_).profile = profile;
 
     U8_TRACE_END();
 }
@@ -93,9 +107,12 @@ void pencil_layouter_destroy( pencil_layouter_t *this_ )
     U8_TRACE_END();
 }
 
-void pencil_layouter_define_grid ( pencil_layouter_t *this_, geometry_rectangle_t diagram_bounds )
+void pencil_layouter_define_grid ( pencil_layouter_t *this_,
+                                   geometry_rectangle_t diagram_bounds,
+                                   PangoLayout *font_layout )
 {
     U8_TRACE_BEGIN();
+    geometry_rectangle_trace( &diagram_bounds );
 
     /* get the diagram data */
     layout_diagram_t *the_diagram;
@@ -103,32 +120,27 @@ void pencil_layouter_define_grid ( pencil_layouter_t *this_, geometry_rectangle_
     const data_diagram_t *const diagram_data
         = layout_diagram_get_data_const ( the_diagram );
 
-    /* update the bounding rectangle */
-    geometry_rectangle_trace ( &diagram_bounds );
-    layout_diagram_set_bounds( the_diagram, &diagram_bounds );
-
     /* calculate the pencil-sizes and the drawing rectangle */
-    const double width = geometry_rectangle_get_width ( &diagram_bounds );
-    const double height = geometry_rectangle_get_height ( &diagram_bounds );
+    const double width = geometry_rectangle_get_width( &diagram_bounds );
+    const double height = geometry_rectangle_get_height( &diagram_bounds );
     pencil_size_reinit( &((*this_).pencil_size), width, height );
 
-    geometry_rectangle_t diagram_draw_area;
-    geometry_rectangle_init_empty( &diagram_draw_area );
-    pencil_diagram_painter_get_drawing_space ( &((*this_).diagram_painter),
-                                               diagram_data,
-                                               &((*this_).pencil_size),
-                                               &diagram_bounds,
-                                               &diagram_draw_area
-                                             );
-    layout_diagram_set_draw_area( the_diagram, &diagram_draw_area );
-    geometry_rectangle_destroy( &diagram_draw_area );
+    pencil_diagram_painter_do_layout( &((*this_).diagram_painter),
+                                      diagram_data,
+                                      &diagram_bounds,
+                                      &((*this_).pencil_size),
+                                      font_layout,
+                                      the_diagram
+                                    );
+    const geometry_rectangle_t *const diagram_draw_area
+        = layout_diagram_get_draw_area_const( the_diagram );
 
     /* calculate the axis scales */
-    geometry_rectangle_trace ( &diagram_draw_area );
-    const double draw_left = geometry_rectangle_get_left ( &diagram_draw_area );
-    const double draw_top = geometry_rectangle_get_top ( &diagram_draw_area );
-    const double draw_right = geometry_rectangle_get_right ( &diagram_draw_area );
-    const double draw_bottom = geometry_rectangle_get_bottom ( &diagram_draw_area );
+    geometry_rectangle_trace( diagram_draw_area );
+    const double draw_left = geometry_rectangle_get_left( diagram_draw_area );
+    const double draw_top = geometry_rectangle_get_top( diagram_draw_area );
+    const double draw_right = geometry_rectangle_get_right( diagram_draw_area );
+    const double draw_bottom = geometry_rectangle_get_bottom( diagram_draw_area );
     geometry_non_linear_scale_reinit( &((*this_).x_scale), draw_left, draw_right );
     geometry_non_linear_scale_reinit( &((*this_).y_scale), draw_top, draw_bottom );
 
