@@ -15,6 +15,7 @@ void pencil_relationship_painter_init( pencil_relationship_painter_t *this_ )
 
     pencil_marker_init( &((*this_).marker) );
     draw_relationship_label_init( &((*this_).draw_relationship_label) );
+    draw_stereotype_image_init( &((*this_).draw_stereotype_image) );
 
     U8_TRACE_END();
 }
@@ -23,6 +24,7 @@ void pencil_relationship_painter_destroy( pencil_relationship_painter_t *this_ )
 {
     U8_TRACE_BEGIN();
 
+    draw_stereotype_image_destroy( &((*this_).draw_stereotype_image) );
     draw_relationship_label_destroy( &((*this_).draw_relationship_label) );
     pencil_marker_destroy( &((*this_).marker) );
 
@@ -34,13 +36,15 @@ void pencil_relationship_painter_draw ( pencil_relationship_painter_t *this_,
                                         bool mark_focused,
                                         bool mark_highlighted,
                                         bool mark_selected,
+                                        const data_profile_part_t *profile,
                                         const pencil_size_t *pencil_size,
                                         PangoLayout *layout,
                                         cairo_t *cr )
 {
     U8_TRACE_BEGIN();
-    assert( NULL != pencil_size );
     assert( NULL != layouted_relationship );
+    assert( NULL != profile );
+    assert( NULL != pencil_size );
     assert( NULL != layout );
     assert( NULL != cr );
 
@@ -591,8 +595,13 @@ void pencil_relationship_painter_draw ( pencil_relationship_painter_t *this_,
         cairo_set_dash ( cr, NULL, 0, 0.0 );
 
         /* draw the label */
+        const char *const rel_stereotype = data_relationship_get_stereotype_const( the_relationship );
+        const bool has_stereotype_image
+            = draw_stereotype_image_exists( &((*this_).draw_stereotype_image), rel_stereotype, profile );
+
         draw_relationship_label_draw_type_and_name ( &((*this_).draw_relationship_label),
                                                      the_relationship,
+                                                     ( ! has_stereotype_image ),
                                                      layout_relationship_get_label_box_const( layouted_relationship ),
                                                      pencil_size,
                                                      layout,
