@@ -9,12 +9,12 @@
 #include "test_environment_assert.h"
 #include <inttypes.h>
 
-static void set_up(void);
-static void tear_down(void);
-static void layout_good_cases(void);
-static void layout_challenging_cases(void);
+static test_fixture_t * set_up();
+static void tear_down( test_fixture_t *test_env );
+static test_case_result_t layout_good_cases( test_fixture_t *test_env );
+static test_case_result_t layout_challenging_cases( test_fixture_t *test_env );
 #ifndef NDEBUG
-static void layout_edge_cases(void);
+static test_case_result_t layout_edge_cases( test_fixture_t *test_env );
 #endif
 
 /*
@@ -33,41 +33,54 @@ test_suite_t pencil_layouter_test_get_suite(void)
     return result;
 }
 
-static data_visible_set_t data_set;
-static pencil_layouter_t layouter;
-static cairo_surface_t *surface;
-static cairo_t *cr;
-static geometry_rectangle_t diagram_bounds;
-static PangoLayout *font_layout;
+struct fixture_struct {
+    data_visible_set_t data_set;
+    data_profile_part_t profile;
+    pencil_layouter_t layouter;
+    cairo_surface_t *surface;
+    cairo_t *cr;
+    geometry_rectangle_t diagram_bounds;
+    PangoLayout *font_layout;
+};
+typedef struct fixture_struct fixture_t;
+static fixture_t test_environment;
 
-static void set_up(void)
+static test_fixture_t * set_up()
 {
-    data_visible_set_init( &data_set );
-    pencil_layouter_init( &layouter, &data_set );
-    geometry_rectangle_init( &diagram_bounds, 0.0, 0.0, 640.0, 480.0 );
-    surface = cairo_image_surface_create( CAIRO_FORMAT_ARGB32,
-                                          (uint32_t) geometry_rectangle_get_width( &diagram_bounds ),
-                                          (uint32_t) geometry_rectangle_get_height( &diagram_bounds )
-                                        );
-    TEST_ENVIRONMENT_ASSERT( CAIRO_STATUS_SUCCESS == cairo_surface_status( surface ) );
-    cr = cairo_create (surface);
-    TEST_ENVIRONMENT_ASSERT( CAIRO_STATUS_SUCCESS == cairo_status( cr ) );
-    font_layout = pango_cairo_create_layout (cr);
+    fixture_t *fix = &test_environment;
+    data_visible_set_init( &((*fix).data_set) );
+    data_profile_part_init( &((*fix).profile) );
+    pencil_layouter_init( &((*fix).layouter), &((*fix).data_set), &((*fix).profile) );
+    geometry_rectangle_init( &((*fix).diagram_bounds), 0.0, 0.0, 640.0, 480.0 );
+    (*fix).surface = cairo_image_surface_create( CAIRO_FORMAT_ARGB32,
+                                                 (uint32_t) geometry_rectangle_get_width( &((*fix).diagram_bounds) ),
+                                                 (uint32_t) geometry_rectangle_get_height( &((*fix).diagram_bounds) )
+                                               );
+    TEST_ENVIRONMENT_ASSERT( CAIRO_STATUS_SUCCESS == cairo_surface_status( (*fix).surface ) );
+    (*fix).cr = cairo_create( (*fix).surface );
+    TEST_ENVIRONMENT_ASSERT( CAIRO_STATUS_SUCCESS == cairo_status( (*fix).cr ) );
+    (*fix).font_layout = pango_cairo_create_layout( (*fix).cr );
+    return fix;
 }
 
-static void tear_down(void)
+static void tear_down( test_fixture_t *test_env )
 {
-    g_object_unref (font_layout);
-    cairo_destroy (cr);
-    cairo_surface_finish ( surface );
-    cairo_surface_destroy ( surface );
-    geometry_rectangle_destroy( &diagram_bounds );
-    pencil_layouter_destroy( &layouter );
-    data_visible_set_destroy( &data_set );
+    assert( test_env == &test_environment );  /* for this test suite, any other pointer would be wrong */
+    fixture_t *fix = test_env;
+    g_object_unref( (*fix).font_layout );
+    cairo_destroy( (*fix).cr );
+    cairo_surface_finish( (*fix).surface );
+    cairo_surface_destroy( (*fix).surface );
+    geometry_rectangle_destroy( &((*fix).diagram_bounds) );
+    pencil_layouter_destroy( &((*fix).layouter) );
+    data_profile_part_destroy( &((*fix).profile) );
+    data_visible_set_destroy( &((*fix).data_set) );
 }
 
-static void layout_good_cases(void)
+static test_case_result_t layout_good_cases( test_fixture_t *test_env )
 {
+    assert( test_env == &test_environment );  /* for this test suite, any other pointer would be wrong */
+    fixture_t *fix = test_env;
     data_stat_t total_stats;
     data_stat_init( &total_stats );
 
@@ -76,18 +89,18 @@ static void layout_good_cases(void)
     for ( ; test_data_setup_is_valid_variant( &ts_setup ); test_data_setup_next_variant( &ts_setup ) )
     {
         /* setup */
-        test_data_setup_get_variant_data( &ts_setup, &data_set );
+        test_data_setup_get_variant_data( &ts_setup, &((*fix).data_set) );
         data_stat_t layout_stats;
         data_stat_init( &layout_stats );
 
         /* perform test */
-        pencil_layouter_prepare ( &layouter );
-        pencil_layouter_define_grid ( &layouter, diagram_bounds );
-        pencil_layouter_layout_elements ( &layouter, font_layout );
-        pencil_layout_data_get_statistics( pencil_layouter_get_layout_data_const( &layouter ), &layout_stats );
+        pencil_layouter_prepare ( &((*fix).layouter) );
+        pencil_layouter_define_grid ( &((*fix).layouter), (*fix).diagram_bounds, (*fix).font_layout );
+        pencil_layouter_layout_elements ( &((*fix).layouter), (*fix).font_layout );
+        pencil_layout_data_get_statistics( pencil_layouter_get_layout_data_const( &((*fix).layouter) ), &layout_stats );
 
         /* check result */
-        const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const( &layouter );
+        const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const( &((*fix).layouter) );
         TEST_EXPECT( NULL != layout_data );
         /*
         const uint32_t class_cnt = pencil_layout_data_get_visible_classifier_count( layout_data );
@@ -127,10 +140,13 @@ static void layout_good_cases(void)
              data_stat_get_count( &total_stats, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING )
            );
     data_stat_destroy( &total_stats );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void layout_challenging_cases(void)
+static test_case_result_t layout_challenging_cases( test_fixture_t *test_env )
 {
+    assert( test_env == &test_environment );  /* for this test suite, any other pointer would be wrong */
+    fixture_t *fix = test_env;
     data_stat_t total_stats;
     data_stat_init( &total_stats );
 
@@ -139,18 +155,18 @@ static void layout_challenging_cases(void)
     for ( ; test_data_setup_is_valid_variant( &ts_setup ); test_data_setup_next_variant( &ts_setup ) )
     {
         /* setup */
-        test_data_setup_get_variant_data( &ts_setup, &data_set );
+        test_data_setup_get_variant_data( &ts_setup, &((*fix).data_set) );
         data_stat_t layout_stats;
         data_stat_init( &layout_stats );
 
         /* perform test */
-        pencil_layouter_prepare ( &layouter );
-        pencil_layouter_define_grid ( &layouter, diagram_bounds );
-        pencil_layouter_layout_elements ( &layouter, font_layout );
-        pencil_layout_data_get_statistics( pencil_layouter_get_layout_data_const( &layouter ), &layout_stats );
+        pencil_layouter_prepare ( &((*fix).layouter) );
+        pencil_layouter_define_grid ( &((*fix).layouter), (*fix).diagram_bounds, (*fix).font_layout );
+        pencil_layouter_layout_elements ( &((*fix).layouter), (*fix).font_layout );
+        pencil_layout_data_get_statistics( pencil_layouter_get_layout_data_const( &((*fix).layouter) ), &layout_stats );
 
         /* check result */
-        const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const( &layouter );
+        const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const( &((*fix).layouter) );
         TEST_EXPECT( NULL != layout_data );
         /*
         const uint32_t class_cnt = pencil_layout_data_get_visible_classifier_count( layout_data );
@@ -174,25 +190,28 @@ static void layout_challenging_cases(void)
              data_stat_get_count( &total_stats, DATA_TABLE_RELATIONSHIP, DATA_STAT_SERIES_WARNING )
            );
     data_stat_destroy( &total_stats );
+    return TEST_CASE_RESULT_OK;
 }
 
 #ifndef NDEBUG
-static void layout_edge_cases(void)
+static test_case_result_t layout_edge_cases( test_fixture_t *test_env )
 {
+    assert( test_env == &test_environment );  /* for this test suite, any other pointer would be wrong */
+    fixture_t *fix = test_env;
     test_data_setup_t ts_setup;
     test_data_setup_init( &ts_setup, TEST_DATA_SETUP_MODE_EDGE_CASES );
     for ( ; test_data_setup_is_valid_variant( &ts_setup ); test_data_setup_next_variant( &ts_setup ) )
     {
         /* setup */
-        test_data_setup_get_variant_data( &ts_setup, &data_set );
+        test_data_setup_get_variant_data( &ts_setup, &((*fix).data_set) );
 
         /* perform test */
-        pencil_layouter_prepare ( &layouter );
-        pencil_layouter_define_grid ( &layouter, diagram_bounds );
-        pencil_layouter_layout_elements ( &layouter, font_layout );
+        pencil_layouter_prepare ( &((*fix).layouter) );
+        pencil_layouter_define_grid ( &((*fix).layouter), (*fix).diagram_bounds, (*fix).font_layout );
+        pencil_layouter_layout_elements ( &((*fix).layouter), (*fix).font_layout );
 
         /* check result */
-        const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const( &layouter );
+        const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const( &((*fix).layouter) );
         TEST_EXPECT( NULL != layout_data );
         /*
         const uint32_t class_cnt = pencil_layout_data_get_visible_classifier_count( layout_data );
@@ -204,6 +223,7 @@ static void layout_edge_cases(void)
         */
     }
     test_data_setup_destroy( &ts_setup );
+    return TEST_CASE_RESULT_OK;
 }
 #endif
 
