@@ -7,10 +7,10 @@
 #include <string.h>
 #include <assert.h>
 
-static void set_up(void);
-static void tear_down(void);
-static void test_write_regular(void);
-static void test_write_border_cases(void);
+static test_fixture_t * set_up();
+static void tear_down( test_fixture_t *test_env );
+static test_case_result_t test_write_regular( test_fixture_t *test_env );
+static test_case_result_t test_write_border_cases( test_fixture_t *test_env );
 
 static char my_out_buffer[16];
 static universal_memory_output_stream_t my_mem_out_stream;
@@ -26,7 +26,7 @@ test_suite_t universal_escaping_output_stream_test_get_suite(void)
     return result;
 }
 
-static void set_up(void)
+static test_fixture_t * set_up()
 {
     memset( &my_out_buffer, '\0', sizeof(my_out_buffer) );
     universal_memory_output_stream_init( &my_mem_out_stream, &my_out_buffer, sizeof(my_out_buffer) );
@@ -34,9 +34,10 @@ static void set_up(void)
                                            &my_patterns_and_replacements,
                                            universal_memory_output_stream_get_output_stream( &my_mem_out_stream )
                                          );
+    return NULL;
 }
 
-static void tear_down(void)
+static void tear_down( test_fixture_t *test_env )
 {
     int err;
     err = universal_escaping_output_stream_destroy( &my_esc_out_stream );
@@ -44,7 +45,7 @@ static void tear_down(void)
     TEST_ENVIRONMENT_ASSERT( err == 0 );
 }
 
-static void test_write_regular(void)
+static test_case_result_t test_write_regular( test_fixture_t *test_env )
 {
     int err;
 
@@ -74,9 +75,10 @@ static void test_write_regular(void)
     err = universal_output_stream_write ( my_out_stream, test_3, strlen(test_3) );
     TEST_EXPECT_EQUAL_INT( 0, err );
     TEST_EXPECT_EQUAL_INT( 0, strcmp( &(my_out_buffer[0]), "&amp;- - -4  \n" ) );
+    return TEST_CASE_RESULT_OK;
 }
 
-static void test_write_border_cases(void)
+static test_case_result_t test_write_border_cases( test_fixture_t *test_env )
 {
     int err;
 
@@ -106,6 +108,7 @@ static void test_write_border_cases(void)
     err = universal_output_stream_write ( my_out_stream, test_3, sizeof(test_3) );
     TEST_EXPECT_EQUAL_INT( U8_ERROR_AT_FILE_WRITE, err );
     TEST_EXPECT_EQUAL_INT( 0, memcmp( &(my_out_buffer[0]), "&amp;&amp;- - - ", sizeof(my_out_buffer) ) );
+    return TEST_CASE_RESULT_OK;
 }
 
 
